@@ -24,9 +24,8 @@
  
 #include "linphonecore.h"
 #include "private.h"
-#include <eXosip.h>
+#include <eXosip2/eXosip.h>
 #include <osipparser2/osip_message.h>
-#include "eXosip2.h"
 #include "lpconfig.h"
 
 extern LinphoneProxyConfig *linphone_core_get_proxy_config_from_rid(LinphoneCore *lc, int rid);
@@ -42,6 +41,8 @@ LinphoneAuthInfo *linphone_auth_info_new(const char *username, const char *useri
 	if (passwd!=NULL && (strlen(passwd)>0)) obj->passwd=ms_strdup(passwd);
 	if (ha1!=NULL && (strlen(ha1)>0)) obj->ha1=ms_strdup(ha1);
 	if (realm!=NULL && (strlen(realm)>0)) obj->realm=ms_strdup(realm);
+	obj->works=FALSE;
+	obj->first_time=TRUE;
 	return obj;
 }
 
@@ -143,6 +144,8 @@ void linphone_core_add_auth_info(LinphoneCore *lc, LinphoneAuthInfo *info)
 	eXosip_add_authentication_info(info->username,userid,
 				info->passwd,info->ha1,info->realm);
 	eXosip_unlock();
+	/* if the user was prompted, re-allow automatic_action */
+	if (lc->automatic_action>0) lc->automatic_action--;
 	/* find if we are attempting to modify an existing auth info */
 	elem=ms_list_find_custom(lc->auth_info,auth_info_compare,info);
 	if (elem!=NULL){
@@ -153,8 +156,6 @@ void linphone_core_add_auth_info(LinphoneCore *lc, LinphoneAuthInfo *info)
 		lc->auth_info=ms_list_append(lc->auth_info,(void *)info);
 		n=ms_list_size(lc->auth_info)-1;
 	}
-	/* find if we need to restart a register request */
-	linphone_core_retry_proxy_register(lc,info->realm);
 }
 
 void linphone_core_remove_auth_info(LinphoneCore *lc, LinphoneAuthInfo *info){
@@ -190,29 +191,65 @@ void linphone_core_clear_all_auth_info(LinphoneCore *lc){
 	lc->auth_info=NULL;
 }
 
-bool_t linphone_core_find_or_ask_for_auth_info(LinphoneCore *lc,const char *username,const char* realm, bool_t force_ask)
-{
-	if (force_ask || linphone_core_auth_info_find(lc,realm,username)==NULL){
-		if (lc->vtable.auth_info_requested!=NULL) {
-			lc->vtable.auth_info_requested(lc,realm,username);
-		}
-		return FALSE;
-	}else{
-		return TRUE;
+void linphone_authentication_ok(LinphoneCore *lc, eXosip_event_t *ev){
+	char *prx_realm=NULL,*www_realm=NULL;
+	osip_proxy_authorization_t *prx_auth;
+	osip_authorization_t *www_auth;
+	osip_message_t *msg=ev->request;
+	char *username;
+	LinphoneAuthInfo *as=NULL;
+
+	username=osip_uri_get_username(msg->from->url);
+	osip_message_get_proxy_authorization(msg,0,&prx_auth);
+	osip_message_get_authorization(msg,0,&www_auth);
+	if (prx_auth!=NULL)
+		prx_realm=osip_proxy_authorization_get_realm(prx_auth);
+	if (www_auth!=NULL)
+		www_realm=osip_authorization_get_realm(www_auth);
+	
+	if (prx_realm==NULL && www_realm==NULL){
+		ms_message("No authentication info in the request, ignoring");
+		return;
+	}
+	/* see if we already have this auth information , not to ask it everytime to the user */
+	if (prx_realm!=NULL)
+		as=linphone_core_auth_info_find(lc,prx_realm,username);
+	if (www_realm!=NULL) 
+		as=linphone_core_auth_info_find(lc,www_realm,username);
+	if (as){
+		ms_message("Authentication for user=%s realm=%s is working.",username,prx_realm ? prx_realm : www_realm);
+		as->works=TRUE;
 	}
 }
 
-bool_t linphone_process_authentication(LinphoneCore *lc, osip_message_t *resp, LinphoneProxyConfig *cfg, bool_t force_ask)
+
+void linphone_core_find_or_ask_for_auth_info(LinphoneCore *lc,const char *username,const char* realm, int tid)
+{
+	LinphoneAuthInfo *as;
+	if ((as=linphone_core_auth_info_find(lc,realm,username))==NULL || 
+		(as->works==FALSE && as->first_time==FALSE) ) {
+		if (lc->vtable.auth_info_requested!=NULL) {
+			lc->vtable.auth_info_requested(lc,realm,username);
+			lc->automatic_action++;/*suspends eXosip_automatic_action until the user supplies a password */
+		}else{
+			if (as) as->first_time=FALSE;
+		}
+	}
+}
+
+void linphone_process_authentication(LinphoneCore *lc, eXosip_event_t *ev)
 {
 	char *prx_realm=NULL,*www_realm=NULL;
 	osip_proxy_authenticate_t *prx_auth;
 	osip_www_authenticate_t *www_auth;
+	osip_message_t *resp=ev->response;
 	char *username;
-	bool_t have_it=TRUE;
 	
+	gstate_new_state(lc, GSTATE_REG_FAILED, "Authentication required");
+
 	username=osip_uri_get_username(resp->from->url);
-	prx_auth=(osip_proxy_authenticate_t*)osip_list_get(resp->proxy_authenticates,0);
-	www_auth=(osip_proxy_authenticate_t*)osip_list_get(resp->www_authenticates,0);
+	prx_auth=(osip_proxy_authenticate_t*)osip_list_get(&resp->proxy_authenticates,0);
+	www_auth=(osip_proxy_authenticate_t*)osip_list_get(&resp->www_authenticates,0);
 	if (prx_auth!=NULL)
 		prx_realm=osip_proxy_authenticate_get_realm(prx_auth);
 	if (www_auth!=NULL)
@@ -220,60 +257,12 @@ bool_t linphone_process_authentication(LinphoneCore *lc, osip_message_t *resp, L
 	
 	if (prx_realm==NULL && www_realm==NULL){
 		ms_warning("No realm in the server response.");
-		return FALSE;
-	}
-	if (cfg!=NULL) {
-		if (prx_realm!=NULL)
-			linphone_proxy_config_set_realm(cfg,prx_realm);
-		else if (www_realm!=NULL)
-			linphone_proxy_config_set_realm(cfg,www_realm);
+		return;
 	}
 	/* see if we already have this auth information , not to ask it everytime to the user */
 	if (prx_realm!=NULL) 
-		have_it=linphone_core_find_or_ask_for_auth_info(lc,username,prx_realm,force_ask);
+		linphone_core_find_or_ask_for_auth_info(lc,username,prx_realm,ev->tid);
 	if (www_realm!=NULL) 
-		have_it=linphone_core_find_or_ask_for_auth_info(lc,username,www_realm, force_ask) && have_it;
-	return have_it;
+		linphone_core_find_or_ask_for_auth_info(lc,username,www_realm,ev->tid);
 }
 
-void linphone_register_authentication_required(LinphoneCore *lc,eXosip_event_t *ev){
-	osip_message_t *resp;
-	LinphoneProxyConfig *cfg;
-	eXosip_reg_t *reg=eXosip_event_get_reginfo(ev);
-	ms_return_if_fail(reg!=NULL);
-	
-	resp=reg->r_last_tr->last_response;
-	ms_return_if_fail(resp!=NULL);
-	cfg=linphone_core_get_proxy_config_from_rid(lc,ev->rid);
-	ms_return_if_fail(cfg!=NULL);
-	if (cfg->auth_pending)
-		gstate_new_state(lc, GSTATE_REG_FAILED, "Authentication required");
-	if (linphone_process_authentication(lc,resp,cfg,cfg->auth_pending)){
-		/* we have the information, so retry the register */
-		eXosip_lock();
-		eXosip_register(ev->rid,-1);
-		eXosip_unlock();
-	}
-	else
-		gstate_new_state(lc, GSTATE_REG_FAILED, "Authentication required");
-	cfg->auth_pending=TRUE;
-}
-
-void linphone_invite_authentication_required(LinphoneCore* lc,LinphoneCall *lcall)
-{
-	osip_message_t *resp;
-	eXosip_call_t *call=NULL;
-	eXosip_call_find(lcall->cid,&call);
-	ms_return_if_fail(call!=NULL);
-	resp=call->c_out_tr->last_response;
-	ms_return_if_fail(resp!=NULL);
-	if (linphone_process_authentication(lc,resp,NULL,lcall->auth_pending)){
-		eXosip_lock();
-		eXosip_retry_call(lcall->cid);
-		eXosip_unlock();
-	}else{
-		linphone_call_destroy(lcall);
-		lc->call=NULL;
-	}
-	
-}
