@@ -805,6 +805,21 @@ void linphone_registration_success(LinphoneCore *lc,eXosip_event_t *ev){
 	gstate_new_state(lc, GSTATE_REG_OK, NULL);
 }
 
+static void linphone_other_request(LinphoneCore *lc, eXosip_event_t *ev){
+	if (ev->request==NULL) return;
+	if (strcmp(ev->request->sip_method,"MESSAGE")==0){
+		linphone_core_text_received(lc,ev);
+		eXosip_message_send_answer(ev->tid,200,NULL);
+	}else if (strcmp(ev->request->sip_method,"OPTIONS")==0){
+		eXosip_options_send_answer(ev->tid,200,NULL);
+	}
+	else {
+		ms_message("Unsupported request received.");
+		/*answer with a 501 Not implemented*/
+		eXosip_message_send_answer(ev->tid,501,NULL);
+	}
+}
+
 void linphone_core_process_event(LinphoneCore *lc,eXosip_event_t *ev)
 {
 	switch(ev->type){
@@ -890,7 +905,7 @@ void linphone_core_process_event(LinphoneCore *lc,eXosip_event_t *ev)
 			linphone_authentication_ok(lc,ev);
 			break;
 		case EXOSIP_MESSAGE_NEW:
-			linphone_core_text_received(lc,ev);
+			linphone_other_request(lc,ev);
 			break;
 		default:
 			break;
