@@ -312,6 +312,13 @@ void sound_config_read(LinphoneCore *lc)
 	const char **devices;
 	int ndev;
 	int i;
+
+	/*alsadev let the user use custom alsa device within linphone*/
+	devid=lp_config_get_string(lc->config,"sound","alsadev",NULL);
+	if (devid){
+		MSSndCard *card=ms_alsa_card_new_custom(devid,devid);
+		ms_snd_card_manager_add_card(ms_snd_card_manager_get(),card);
+	}
 	/* retrieve all sound devices */
 	elem=ms_snd_card_manager_get_list(ms_snd_card_manager_get());
 	ndev=ms_list_size(elem);
@@ -1048,8 +1055,18 @@ bool_t linphone_core_interpret_url(LinphoneCore *lc, const char *url, char **rea
 			/*if the prompted uri was auto-suffixed with proxy domain,
 			then automatically set a route so that the request goes
 			through the proxy*/
-			if (tmproute==NULL) 
-				*route=ms_strdup(linphone_proxy_config_get_addr(proxy));
+			if (tmproute==NULL){
+				osip_route_t *rt=NULL;
+				char *rtstr=NULL;
+				osip_route_init(&rt);
+				if (osip_route_parse(rt,linphone_proxy_config_get_addr(proxy))==0){
+					osip_uri_uparam_add(rt->url,osip_strdup("lr"),NULL);
+					osip_route_to_str(rt,&rtstr);
+					*route=ms_strdup(rtstr);
+					osip_free(rtstr);
+				}
+				ms_message("setting automatically a route to %s",*route);
+			}
 			else *route=ms_strdup(tmproute);
 			return TRUE;
 		}
