@@ -55,6 +55,7 @@ typedef struct sip_config
 	bool_t guess_hostname;
 	bool_t loopback_only;
 	bool_t ipv6_enabled;
+	bool_t sdp_200_ack;
 } sip_config_t;
 
 typedef struct rtp_config
@@ -103,8 +104,9 @@ typedef struct codecs_config
 
 typedef struct video_config{
 	char *device;
-	bool_t enabled;
+	bool_t capture;
 	bool_t show_local;
+	bool_t display;
 }video_config_t;
 
 typedef struct ui_config
@@ -159,6 +161,7 @@ typedef struct _LinphoneCall
 	struct _LinphoneCallLog *log;
 	int cid; /*call id */
 	int did; /*dialog id */
+	int tid; /*last transaction id*/
 	struct _sdp_context *sdpctx;
 	time_t start_time;
 	LCState	state;
@@ -166,8 +169,7 @@ typedef struct _LinphoneCall
 } LinphoneCall;
 
 LinphoneCall * linphone_call_new_outgoing(struct _LinphoneCore *lc, const osip_from_t *from, const osip_to_t *to);
-LinphoneCall * linphone_call_new_incoming(struct _LinphoneCore *lc, const char *from, const char *to,
-											int cid, int did);
+LinphoneCall * linphone_call_new_incoming(struct _LinphoneCore *lc, const char *from, const char *to, int cid, int did , int tid);
 #define linphone_call_set_state(lcall,st)	(lcall)->state=(st)
 void linphone_call_destroy(struct _LinphoneCall *obj);
 
@@ -204,10 +206,10 @@ typedef enum{
 
 typedef struct _LinphoneFriend{
 	osip_from_t *url;
-	char *contact;	/* not stored, use for immediate outgoing subscribe after receiving incoming subscribe*/
+	int in_did;
+	int out_did;
 	int sid;
 	int nid;
-	int last_outsubsc;
 	LinphoneSubscribePolicy pol;
 	struct _LinphoneProxyConfig *proxy;
 	struct _LinphoneCore *lc;
@@ -277,6 +279,7 @@ typedef struct _LinphoneAuthInfo
 	char *passwd;
 	char *ha1;
 	bool_t works;
+	bool_t first_time;
 }LinphoneAuthInfo;
 
 LinphoneAuthInfo *linphone_auth_info_new(const char *username, const char *userid,
@@ -289,6 +292,7 @@ LinphoneAuthInfo * linphone_auth_info_new_from_config_file(struct _LpConfig *con
 struct _LinphoneChatRoom{
 	struct _LinphoneCore *lc;
 	char  *peer;
+	char *route;
 	osip_from_t *peer_url;
 	void * user_data;
 };
@@ -399,6 +403,8 @@ typedef enum _LinphoneOnlineStatus{
 	LINPHONE_STATUS_MOVED,
 	LINPHONE_STATUS_ALT_SERVICE,
 	LINPHONE_STATUS_OFFLINE,
+	LINPHONE_STATUS_PENDING,
+	LINPHONE_STATUS_CLOSED,
 	LINPHONE_STATUS_END
 }LinphoneOnlineStatus;
 
@@ -439,7 +445,8 @@ typedef struct _LinphoneCore
 	struct _RtpProfile *local_profile;
 	MSList *subscribers;	/* unknown subscribers */
 	int minutes_away;
-	LinphoneOnlineStatus	presence_mode;
+	LinphoneOnlineStatus presence_mode;
+	LinphoneOnlineStatus prev_mode;
 	char *alt_contact;
 	void *data;
 	ms_mutex_t lock;
@@ -450,6 +457,7 @@ typedef struct _LinphoneCore
 	int up_audio_bw;
 	int dw_video_bw;
 	int up_video_bw;
+	int automatic_action;
 	bool_t use_files;
 	bool_t apply_nat_settings;
 #ifdef VINCENT_MAURY_RSVP
@@ -464,6 +472,7 @@ typedef struct _LinphoneCore
 /* THE main API */
 
 void linphone_core_enable_logs(FILE *file);
+void linphone_core_enable_logs_with_cb(OrtpLogFunc logfunc);
 void linphone_core_disable_logs(void);
 
 const char *linphone_core_get_version(void);
@@ -621,7 +630,7 @@ void linphone_core_notify_all_friends(LinphoneCore *lc, LinphoneOnlineStatus os)
 MSList * linphone_core_get_call_logs(LinphoneCore *lc);
 
 /* video support */
-void linphone_core_enable_video(LinphoneCore *lc, bool_t val);
+void linphone_core_enable_video(LinphoneCore *lc, bool_t vcap_enabled, bool_t display_enabled);
 bool_t linphone_core_video_enabled(LinphoneCore *lc);
 
 /*play/record support: use files instead of soundcard*/
@@ -657,7 +666,7 @@ void linphone_core_start_media_streams(LinphoneCore *lc, LinphoneCall *call);
 void linphone_core_stop_media_streams(LinphoneCore *lc);
 const char * linphone_core_get_identity(LinphoneCore *lc);
 const char * linphone_core_get_route(LinphoneCore *lc);
-bool_t linphone_core_interpret_url(LinphoneCore *lc, const char *url, char **real_url, osip_to_t **real_parsed_url);
+bool_t linphone_core_interpret_url(LinphoneCore *lc, const char *url, char **real_url, osip_to_t **real_parsed_url, char **route);
 
 #ifdef __cplusplus
 }
