@@ -240,7 +240,7 @@ MSList *fix_codec_list(RtpProfile *prof, MSList *conflist)
 	{
 		confpayload=(PayloadType*)elem->data;
 		payload=rtp_profile_find_payload(prof,confpayload->mime_type,
-								confpayload->clock_rate);
+								confpayload->clock_rate,-1);
 		if (payload!=NULL){
 			if (ms_filter_codec_supported(confpayload->mime_type)){
 				MSFilterDesc *desc=ms_filter_get_encoder(confpayload->mime_type);
@@ -326,10 +326,10 @@ int from_2char_without_params(osip_from_t *from,char **str)
 	osip_from_t *tmpfrom=NULL;
 	osip_from_clone(from,&tmpfrom);
 	if (tmpfrom!=NULL){
-		while(!osip_list_eol(tmpfrom->gen_params,0)){
-			osip_generic_param_t *param=(osip_generic_param_t*)osip_list_get(tmpfrom->gen_params,0);
+		while(!osip_list_eol(&tmpfrom->gen_params,0)){
+			osip_generic_param_t *param=(osip_generic_param_t*)osip_list_get(&tmpfrom->gen_params,0);
 			osip_generic_param_free(param);
-			osip_list_remove(tmpfrom->gen_params,0);
+			osip_list_remove(&tmpfrom->gen_params,0);
 		}
 	}else return -1;
 	osip_from_to_str(tmpfrom,str);
