@@ -18,44 +18,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "linphonecore.h"
-#include <eXosip.h>
+#include <eXosip2/eXosip.h>
 #include <osipparser2/osip_message.h>
 #include "private.h"
 
-extern int linphone_friend_set_contact(LinphoneFriend *lf, const char *contact);
-extern MSList *find_friend(MSList *fl, const char *friend, LinphoneFriend **lf);
+
 extern const char *__policy_enum_to_str(LinphoneSubscribePolicy pol);
 
-int linphone_online_status_to_eXosip(LinphoneOnlineStatus os){
-	static int convtable[LINPHONE_STATUS_END];
-	static bool_t initialized=FALSE;
-	if (!initialized){
-		convtable[LINPHONE_STATUS_AWAY]=EXOSIP_NOTIFY_AWAY;
-		convtable[LINPHONE_STATUS_UNKNOWN]=EXOSIP_NOTIFY_UNKNOWN;
-		convtable[LINPHONE_STATUS_ONLINE]=EXOSIP_NOTIFY_ONLINE;
-		convtable[LINPHONE_STATUS_BUSY]=EXOSIP_NOTIFY_BUSY;
 
-		/* added by amd */
-		convtable[LINPHONE_STATUS_BERIGHTBACK]=EXOSIP_NOTIFY_BERIGHTBACK;
-		convtable[LINPHONE_STATUS_ONTHEPHONE]=EXOSIP_NOTIFY_ONTHEPHONE;
-		convtable[LINPHONE_STATUS_OUTTOLUNCH]=EXOSIP_NOTIFY_OUTTOLUNCH;
-		convtable[LINPHONE_STATUS_NOT_DISTURB]=EXOSIP_NOTIFY_BUSY;
-		convtable[LINPHONE_STATUS_MOVED]=EXOSIP_NOTIFY_AWAY;
-		convtable[LINPHONE_STATUS_ALT_SERVICE]=EXOSIP_NOTIFY_AWAY;
-
-		convtable[LINPHONE_STATUS_OFFLINE]=EXOSIP_NOTIFY_CLOSED;
-
-		initialized=TRUE;
-	}
-	return convtable[os];
-}
-
-
-void linphone_core_add_subscriber(LinphoneCore *lc, const char *subscriber, const char *contact, int did){
+void linphone_core_add_subscriber(LinphoneCore *lc, const char *subscriber, int did, int nid){
 	LinphoneFriend *fl=linphone_friend_new_with_addr(subscriber);
 	if (fl==NULL) return ;
-	linphone_friend_set_nid(fl,did);
-	linphone_friend_set_contact(fl,contact);
+	fl->in_did=did;
+	linphone_friend_set_nid(fl,nid);
 	linphone_friend_set_inc_subscribe_policy(fl,LinphoneSPAccept);
 	fl->inc_subscribe_pending=TRUE;
 	lc->subscribers=ms_list_append(lc->subscribers,(void *)fl);
@@ -69,9 +44,6 @@ void linphone_core_add_subscriber(LinphoneCore *lc, const char *subscriber, cons
 
 void linphone_core_reject_subscriber(LinphoneCore *lc, LinphoneFriend *lf){
 	linphone_friend_set_inc_subscribe_policy(lf,LinphoneSPDeny);
-	eXosip_lock();
-	eXosip_notify_accept_subscribe(lf->nid,200,EXOSIP_SUBCRSTATE_TERMINATED,EXOSIP_NOTIFY_CLOSED);
-	eXosip_unlock();
 }
 
 static void __do_notify(void * data, void * user_data){
@@ -88,9 +60,8 @@ void __linphone_core_notify_all_friends(LinphoneCore *lc, int ss, int os){
 }
 
 void linphone_core_notify_all_friends(LinphoneCore *lc, LinphoneOnlineStatus os){
-	int ss=linphone_online_status_to_eXosip(os);
-	ms_message("Notifying all friends that we are in status %i/%i",os,ss);
-	__linphone_core_notify_all_friends(lc,EXOSIP_SUBCRSTATE_ACTIVE,ss);
+	ms_message("Notifying all friends that we are in status %i",os);
+	__linphone_core_notify_all_friends(lc,EXOSIP_SUBCRSTATE_ACTIVE,os);
 }
 
 /* check presence state before answering to call; returns TRUE if we can proceed, else answer the appropriate answer
@@ -99,109 +70,128 @@ bool_t linphone_core_check_presence(LinphoneCore *lc){
 	return TRUE;
 }
 
-void linphone_subscription_new(LinphoneCore *lc, int did,int sid, char *from, char *contact){
+void linphone_subscription_new(LinphoneCore *lc, eXosip_event_t *ev){
 	LinphoneFriend *lf=NULL;
-	
-	ms_message("Receiving new subscription from %s.",from);
+	osip_from_t *from=ev->request->from;
+	char *tmp;
+	osip_message_t *msg=NULL;
+
+	osip_from_to_str(ev->request->from,&tmp);
+
+	ms_message("Receiving new subscription from %s.",tmp);
 	/* check if we answer to this subscription */
 	if (find_friend(lc->friends,from,&lf)!=NULL){
-		linphone_friend_set_nid(lf,did);
+		lf->in_did=ev->did;
+		linphone_friend_set_nid(lf,ev->nid);
+		eXosip_insubscription_build_answer(ev->tid,202,&msg);
+		eXosip_insubscription_send_answer(ev->tid,202,msg);
+		__eXosip_wakeup_event();
 		linphone_friend_done(lf);	/*this will do all necessary actions */
 	}else{
 		/* check if this subscriber is in our black list */
 		if (find_friend(lc->subscribers,from,&lf)){
 			if (lf->pol==LinphoneSPDeny){
 				ms_message("Rejecting %s because we already rejected it once.",from);
-				linphone_core_reject_subscriber(lc,lf);
+				eXosip_insubscription_send_answer(ev->tid,401,NULL);
 			}
 			else {
 				/* else it is in wait for approval state, because otherwise it is in the friend list.*/
 				ms_message("New subscriber found in friend list, in %s state.",__policy_enum_to_str(lf->pol));
 			}
-		}else linphone_core_add_subscriber(lc,from,contact,did);
+		}else {
+			eXosip_insubscription_build_answer(ev->tid,202,&msg);
+			eXosip_insubscription_send_answer(ev->tid,202,msg);
+			linphone_core_add_subscriber(lc,tmp,ev->did,ev->nid);
+		}
 	}
+	osip_free(tmp);
 }
 
-void linphone_notify_recv(LinphoneCore *lc,char *from,int online_status)
+void linphone_notify_recv(LinphoneCore *lc, eXosip_event_t *ev)
 {
-	char *status;
-	char *img;
+	const char *status=_("Gone");
+	const char *img="sip-closed.png";
 	char *tmp;
 	LinphoneFriend *lf;
 	osip_from_t *friend=NULL;
-	switch (online_status){
-		case EXOSIP_NOTIFY_PENDING:
+	osip_from_t *from=NULL;
+	osip_body_t *body=NULL;
+	ms_message("Receiving notify with sid=%i,nid=%i",ev->sid,ev->nid);
+	if (ev->request!=NULL){
+		from=ev->request->from;
+		osip_message_get_body(ev->request,0,&body);
+		
+		if (strstr(body->body,"pending")!=NULL){
 			status=_("Waiting for Approval");
 			img="sip-wfa.png";
-			break;
-		case EXOSIP_NOTIFY_ONLINE:
+		}else if (strstr(body->body,"online")!=NULL){
 			status=_("Online");
 			img="sip-online.png";
-			break;
-		case EXOSIP_NOTIFY_BUSY:
+		}else if (strstr(body->body,"busy")!=NULL){
 			status=_("Busy");
 			img="sip-busy.png";
-			break;
-		case EXOSIP_NOTIFY_BERIGHTBACK:
+		}else if (strstr(body->body,"berightback")!=NULL
+				|| strstr(body->body,"in-transit")!=NULL ){
 			status=_("Be Right Back");
 			img="sip-bifm.png";
-			break;
-		case EXOSIP_NOTIFY_AWAY:
+		}else if (strstr(body->body,"away")!=NULL){
 			status=_("Away");
 			img="sip-away.png";
-			break;
-		case EXOSIP_NOTIFY_ONTHEPHONE:
+		}else if (strstr(body->body,"onthephone")!=NULL
+			|| strstr(body->body,"on-the-phone")!=NULL){
 			status=_("On The Phone");
 			img="sip-otp.png";
-			break;
-		case EXOSIP_NOTIFY_OUTTOLUNCH:
+		}else if (strstr(body->body,"outtolunch")!=NULL
+				|| strstr(body->body,"meal")!=NULL){
 			status=_("Out To Lunch");
 			img="sip-otl.png";
-			break;
-		case EXOSIP_NOTIFY_CLOSED:
+		}else if (strstr(body->body,"closed")!=NULL){
 			status=_("Closed");
 			img="sip-away.png";
-			break;
-		case EXOSIP_NOTIFY_UNKNOWN:
+		}else if (strstr(body->body,"open")!=NULL){
+			status=_("Online");
+			img="sip-online.png";
+		}else{
 			status=_("Gone");
 			img="sip-closed.png";
-			break;
-		default:
-			ms_warning("Notify status not understood (%i)",online_status);
-			status="unavailable";
-			img="sip-away.png";
-			break;
+		}
+		ms_message("We are notified that sip:%s@%s has online status %s",from->url->username,from->url->host,status);
 	}
-	/* find a friend in our list that matches the from (from may contain tags and other confusing things)*/
-	find_friend(lc->friends,from,&lf);
-	ms_message("We are notified that %s has online status %i",from,online_status);
+	lf=linphone_find_friend_by_sid(lc->friends,ev->sid);
 	if (lf!=NULL){
 		friend=lf->url;
 		from_2char_without_params(friend,&tmp);
 		lc->vtable.notify_recv(lc,(LinphoneFriend*)lf,tmp,status,img);
 		ms_free(tmp);
-		if (online_status==EXOSIP_NOTIFY_CLOSED 
-			|| online_status==EXOSIP_NOTIFY_UNKNOWN) lf->sid=-1;
+		if (ev->ss_status==EXOSIP_SUBCRSTATE_TERMINATED) {
+			lf->sid=-1;
+			lf->out_did=-1;
+			ms_message("Outgoing subscription terminated by remote.");
+		}
 	}else{
 		ms_message("But this person is not part of our friend list, so we don't care.");
 	}
 }
 
-void linphone_subscription_answered(LinphoneCore *lc,char *from, int sid){
+void linphone_subscription_answered(LinphoneCore *lc, eXosip_event_t *ev){
 	LinphoneFriend *lf;
+	osip_from_t *from=ev->response->to;
 	find_friend(lc->friends,from,&lf);
 	if (lf!=NULL){
-		linphone_friend_set_sid(lf,sid);
+		lf->out_did=ev->did;
+		linphone_friend_set_sid(lf,ev->sid);
 	}else{
-		ms_warning("Receiving answer for unknown subscribe to %s", from);
+		ms_warning("Receiving answer for unknown subscribe sip:%s@%s", from->url->username,from->url->host);
 	}
 }
-void linphone_subscription_closed(LinphoneCore *lc,char *from, int did){
+void linphone_subscription_closed(LinphoneCore *lc,eXosip_event_t *ev){
 	LinphoneFriend *lf;
-	find_friend(lc->friends,from,&lf);
+	osip_from_t *from=ev->request->from;
+	lf=linphone_find_friend_by_nid(lc->friends,ev->nid);
 	if (lf!=NULL){
-		linphone_friend_set_sid(lf,-1);
+		lf->in_did=-1;
+		linphone_friend_set_nid(lf,-1);
 	}else{
-		ms_warning("Receiving close for unknown subscribe to %s", from);
+		ms_warning("Receiving unsuscribe for unknown in-subscribtion from sip:%s@%s", from->url->username, from->url->host);
 	}
 }
