@@ -490,6 +490,8 @@ on_authentication_dialog_response      (GtkDialog       *dialog,
 			authentication_dialog_ok(GTK_WIDGET(dialog));
 			gtk_widget_destroy(GTK_WIDGET(dialog));
 			break;
+		case GTK_RESPONSE_CANCEL:
+			gtk_widget_destroy(GTK_WIDGET(dialog));
 	}
 }
 
@@ -569,6 +571,7 @@ on_callbutton_clicked                  (GtkButton       *button,
 		if (err==0) completion_add_text(entry,sipurl);
 	}else {
 		linphone_core_accept_call(lc,NULL);
+		gdk_window_set_keep_above (ui->main_window.window->window, 0);
 	}
 }
 
@@ -578,8 +581,8 @@ on_hangup_clicked                      (GtkButton       *button,
 {
 	LinphoneGnomeUI *ui=get_uiobj();
 	LinphoneCore *lc=get_core();
+	gdk_window_set_keep_above (ui->main_window.window->window, 0);
 	if (lc->call!=NULL){
-		/* same trick here as for linphone_core_accept_dialog: defer it to gtk's idle loop */
 		gtk_window_set_title(GTK_WINDOW(ui->main_window.window),"linphone");
 		linphone_core_terminate_call(lc,NULL);
 	}
@@ -686,7 +689,8 @@ void
 on_video_enabled_toggled               (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
 {
-	linphone_core_enable_video(get_core(),gtk_toggle_button_get_active(togglebutton));
+	bool_t enabled=gtk_toggle_button_get_active(togglebutton);
+	linphone_core_enable_video(get_core(),enabled,enabled);
 }
 
 
