@@ -67,7 +67,12 @@ typedef enum MSFilterId{
 	MS_MJPEG_DEC_ID,
 	MS_JOIN_ID,
 	MS_RESAMPLE_ID,
-	MS_VIDEO_OUT_ID
+	MS_VIDEO_OUT_ID,
+	MS_VOLUME_ID,
+	MS_SNOW_DEC_ID,
+	MS_SNOW_ENC_ID,
+	MS_CA_READ_ID,
+	MS_CA_WRITE_ID
 } MSFilterId;
 
 
