@@ -122,15 +122,18 @@ int video_stream_start(VideoStream * stream, RtpProfile *profile, const char *re
 void video_stream_set_rtcp_information(VideoStream *st, const char *cname, const char *tool);
 /*function to call periodically to handle various events */
 void video_stream_iterate(VideoStream *stream);
+void video_stream_send_vfu(VideoStream *stream);
 void video_stream_stop (VideoStream * stream);
 
 VideoStream * video_preview_start(const char *device);
 void video_preview_stop(VideoStream *stream);
 
-VideoStream * video_stream_send_only_start(RtpProfile *profile, int locport, const char *remip, int remport, int payload, const char *device);
-
+int video_stream_recv_only_start(VideoStream * stream, RtpProfile *profile, const char *remip, int remport, int payload, int jitt_comp, const char *device);
+int video_stream_send_only_start(VideoStream * stream, RtpProfile *profile, const char *remip, int remport, int payload, int jitt_comp, const char *device);
+void video_stream_recv_only_stop(VideoStream *stream);
 void video_stream_send_only_stop(VideoStream *stream);
 
+
 bool_t ms_is_ipv6(const char *address);
 
 #ifdef __cplusplus
