@@ -121,15 +121,60 @@ MSList *ms_list_insert_sorted(MSList *list, void *data, int (*compare_func)(cons
 #undef MAX
 #define MAX(a,b)	((a)>(b) ? (a) : (b))
 
+/**
+ * @file mscommon.h
+ * @brief mediastreamer2 mscommon.h include file
+ *
+ * This file provide the API needed to initialize
+ * and reset the mediastreamer2 library.
+ *
+ */
 
+/**
+ * @defgroup mediastreamer2_init Init API - manage mediastreamer2 library.
+ * @ingroup mediastreamer2_api
+ * @{
+ */
+
+
+/**
+ * Initialize the mediastreamer2 library.
+ *
+ * This must be called once before calling any other API.
+ */
 void ms_init(void);
+
+/**
+ * Load plugins from a specific directory.
+ *
+ * @param directory   A directory where plugins library are available.
+ *
+ * Returns: >0 if successfull, 0 if not plugins loaded, -1 otherwise.
+ */
 int ms_load_plugins(const char *directory);
+
+/**
+ * Release resource allocated in the mediastreamer2 library.
+ *
+ * This must be called once before closing program.
+ */
 void ms_exit(void);
 
 struct _MSSndCardDesc;
 
+/**
+ * This can be called when new sound cards have been added.
+ *
+ * Warning: It must NOT be called if one filter is currently created.
+ * You have to unlink, destroy everything before doing this.
+ *
+ * @param snd_desc   A MSSndCardDesc description.
+ */
 void ms_reload_snd_card(struct _MSSndCardDesc *snd_desc);
 
+void ms_sleep(int seconds);
+
+/** @} */
 
 #ifdef __cplusplus
 }
