@@ -44,13 +44,17 @@ static inline mblk_t *ms_queue_get(MSQueue *q){
 
 static inline void ms_queue_put(MSQueue *q, mblk_t *m){
 	putq(&q->q,m);
-    return;
+	return;
 }
 
 static inline mblk_t * ms_queue_peek_last(MSQueue *q){
 	return qlast(&q->q);
 }
 
+static inline bool_t ms_queue_empty(MSQueue *q){
+	return qempty(&q->q);
+}
+
 void ms_queue_flush(MSQueue *q);
 
 void ms_queue_destroy(MSQueue *q);
@@ -64,6 +68,7 @@ void ms_queue_destroy(MSQueue *q);
 #define mblk_set_payload_type(m,bits) (m)->reserved2=((m)->reserved2|(bits<<3))
 #define mblk_get_payload_type(m)      (((m)->reserved2>>3)&0xFF)
 
+
 struct _MSBufferizer{
 	queue_t q;
 	int size;
@@ -71,8 +76,13 @@ struct _MSBufferizer{
 
 typedef struct _MSBufferizer MSBufferizer;
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 /*allocates and initialize */
-MSBufferizer * ms_bufferizer_new();
+MSBufferizer * ms_bufferizer_new(void);
 
 /*initialize in memory */
 void ms_bufferizer_init(MSBufferizer *obj);
@@ -93,4 +103,8 @@ void ms_bufferizer_uninit(MSBufferizer *obj);
 
 void ms_bufferizer_destroy(MSBufferizer *obj);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
