@@ -63,12 +63,31 @@ typedef enum{
 	MS_YUV420P,
 	MS_YUYV,
 	MS_RGB24,
-	MS_MJPEG
+	MS_MJPEG,
+	MS_UYVY,
+	MS_YUY2   /* -> same as MS_YUYV */
 }MSPixFmt;
 
+typedef struct _YuvBuf{
+	int w,h;
+	uint8_t *planes[4]; /*we usually use 3 planes, 4th is for compatibility */
+	int strides[4];	/*with ffmpeg's swscale.h */
+}YuvBuf;
+
+#ifdef __cplusplus
+extern "C"{
+#endif
+
 int ms_pix_fmt_to_ffmpeg(MSPixFmt fmt);
 MSPixFmt ffmpeg_pix_fmt_to_ms(int fmt);
-void ms_ffmpeg_check_init();
+void ms_ffmpeg_check_init(void);
+int yuv_buf_init_from_mblk(YuvBuf *buf, mblk_t *m);
+void yuv_buf_init_from_mblk_with_size(YuvBuf *buf, mblk_t *m, int w, int h);
+mblk_t * yuv_buf_alloc(YuvBuf *buf, int w, int h);
+
+#ifdef __cplusplus
+}
+#endif
 
 #define MS_FILTER_SET_VIDEO_SIZE	MS_FILTER_BASE_METHOD(100,MSVideoSize)
 #define MS_FILTER_GET_VIDEO_SIZE	MS_FILTER_BASE_METHOD(101,MSVideoSize)
@@ -79,6 +98,7 @@ void ms_ffmpeg_check_init();
 #define MS_FILTER_SET_FPS		MS_FILTER_BASE_METHOD(104,float)
 #define MS_FILTER_GET_FPS		MS_FILTER_BASE_METHOD(105,float)
 
-
+/* request a video-fast-update (=I frame for H263,MP4V-ES) to a video encoder*/
+#define MS_FILTER_REQ_VFU		MS_FILTER_BASE_METHOD_NO_ARG(106)
 
 #endif
