@@ -27,7 +27,7 @@ typedef struct _AlawEncData{
 } AlawEncData;
 
 static AlawEncData * alaw_enc_data_new(){
-	AlawEncData *obj=ms_new(AlawEncData,1);
+	AlawEncData *obj=(AlawEncData *)ms_new(AlawEncData,1);
 	obj->bz=ms_bufferizer_new();
 	obj->ptime=0;
 	obj->ts=0;
@@ -84,6 +84,17 @@ static void alaw_enc_process(MSFilter *obj){
 	}
 }
 
+static int enc_add_fmtp(MSFilter *f, void *arg){
+	const char *fmtp=(const char *)arg;
+	AlawEncData *s=(AlawEncData*)f->data;
+	char tmp[30];
+	if (fmtp_get_value(fmtp,"ptime",tmp,sizeof(tmp))){
+		s->ptime=atoi(tmp);
+		ms_message("MSAlawEnc: got ptime=%i",s->ptime);
+	}
+	return 0;
+}
+
 static int enc_add_attr(MSFilter *f, void *arg){
 	const char *fmtp=(const char *)arg;
 	AlawEncData *s=(AlawEncData*)f->data;
@@ -120,7 +131,8 @@ static int enc_add_attr(MSFilter *f, void *arg){
 }
 
 static MSFilterMethod enc_methods[]={
-	{	MS_FILTER_ADD_ATTR			,	enc_add_attr},
+	{	MS_FILTER_ADD_ATTR		,	enc_add_attr},
+	{	MS_FILTER_ADD_FMTP		,	enc_add_fmtp},
 	{	0				,	NULL		}
 };
 
