@@ -483,7 +483,6 @@ static void alsa_card_uninit(MSSndCard *obj){
 	if (ad->mixdev!=NULL) ms_free(ad->mixdev);
 }
 
-
 static void alsa_card_detect(MSSndCardManager *m){
 	int i;
 	for (i=-1;i<10;i++){
@@ -516,6 +515,17 @@ static MSSndCard *alsa_card_duplicate(MSSndCard *obj){
 	return obj;
 }
 
+MSSndCard * ms_alsa_card_new_custom(const char *pcmdev, const char *mixdev){
+	MSSndCard * obj;
+	AlsaData *ad;
+	obj=ms_snd_card_new(&alsa_card_desc);
+	ad=(AlsaData*)obj->data;
+	obj->name=ms_strdup(pcmdev);
+	ad->pcmdev=ms_strdup(pcmdev);
+	ad->mixdev=ms_strdup(mixdev);
+	return obj;
+}
+
 static MSSndCard * alsa_card_new(int id)
 {
 	MSSndCard * obj;
@@ -542,8 +552,8 @@ static MSSndCard * alsa_card_new(int id)
 		pos2=pos1+strlen(pos1)-1;
 		for (; pos2>pos1 && *pos2==' '; pos2--) *pos2='\0';
 		obj->name=pos1;
-		ad->pcmdev=ms_strdup_printf("plughw:%i,0",id);
-		ad->mixdev=ms_strdup_printf("hw:%i",id);
+		ad->pcmdev=ms_strdup_printf("default:%i",id);
+		ad->mixdev=ms_strdup_printf("default:%i",id);
 	}
 	free(name);
 	/*ms_message("alsa device %s found",obj->name);*/
