@@ -122,7 +122,7 @@ static void channel_uninit(Channel *chan){
 }
 
 static void conf_init(MSFilter *f){
-	ConfState *s=ms_new0(ConfState,1);
+	ConfState *s=(ConfState *)ms_new0(ConfState,1);
 	int i;
 	s->samplerate=8000;
 	s->conf_gran=CONF_GRAN;
@@ -211,7 +211,7 @@ static void conf_sum(ConfState *s){
 	chan=&s->channels[0];
 	if (s->adaptative_msconf_buf*s->conf_gran<ms_bufferizer_get_avail(&chan->buff))
 	{
-		int i = ms_bufferizer_get_avail(&chan->buff)/s->conf_gran;
+		i = ms_bufferizer_get_avail(&chan->buff)/s->conf_gran;
 		if (i>5)
 			ms_message("Increasing buffer because sound card is late. (nb_buf=%i /old=%i)", i, s->adaptative_msconf_buf);
 		s->adaptative_msconf_buf=i;
