@@ -130,7 +130,7 @@ static void player_uninit(MSFilter *f){
 
 static void swap_bytes(unsigned char *bytes, int len){
 	int i;
-	char tmp;
+	unsigned char tmp;
 	for(i=0;i<len;i+=2){
 		tmp=bytes[i];
 		bytes[i]=bytes[i+1];
@@ -160,10 +160,19 @@ static void player_process(MSFilter *f){
 			}else freemsg(om);
 			if (err<bytes){
 				ms_filter_notify_no_arg(f,MS_FILE_PLAYER_EOF);
+				lseek(d->fd,d->hsize,SEEK_SET);
+
+				/* special value for playing file only once */
+				if (d->loop_after==-2)
+				{
+					d->state=STOPPED;
+					ms_filter_unlock(f);
+					return;
+				}
+
 				if (d->loop_after>=0){
-					lseek(d->fd,d->hsize,SEEK_SET);
 					d->pause_time=d->loop_after;
-				}else d->state=STOPPED;
+				}
 			}
 		}else{
 			ms_warning("Fail to read %i bytes: %s",bytes,strerror(errno));
