@@ -38,7 +38,7 @@ typedef struct SenderData SenderData;
 
 static void sender_init(MSFilter * f)
 {
-	SenderData *d = ms_new(SenderData, 1);
+	SenderData *d = (SenderData *)ms_new(SenderData, 1);
 
 	d->session = NULL;
 	d->cpair = NULL;
@@ -262,7 +262,7 @@ typedef struct ReceiverData ReceiverData;
 
 static void receiver_init(MSFilter * f)
 {
-	ReceiverData *d = ms_new(ReceiverData, 1);
+	ReceiverData *d = (ReceiverData *)ms_new(ReceiverData, 1);
 
 	d->ortp_event = ortp_ev_queue_new();
 	d->session = NULL;
@@ -388,7 +388,7 @@ MSFilterDesc ms_rtp_recv_desc = {
 	0,
 	1,
 	receiver_init,
-	receiver_process,
+	receiver_preprocess,
 	receiver_process,
 	receiver_postprocess,
 	receiver_uninit,
