@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 static MSSndCardManager *scm=NULL;
 
 static MSSndCardManager * create_manager(){
-	MSSndCardManager *obj=ms_new(MSSndCardManager,1);
+	MSSndCardManager *obj=(MSSndCardManager *)ms_new(MSSndCardManager,1);
 	obj->cards=NULL;
 	return obj;
 }
@@ -51,7 +51,13 @@ MSSndCard * ms_snd_card_manager_get_card(MSSndCardManager *m, const char *id){
 }
 
 MSSndCard * ms_snd_card_manager_get_default_card(MSSndCardManager *m){
-	if (m->cards!=NULL) return (MSSndCard*)m->cards->data;
+	/*return the first card that has the capture+playback capability */
+	MSList *elem;
+	for (elem=m->cards;elem!=NULL;elem=elem->next){
+		MSSndCard *card=(MSSndCard*)elem->data;
+		if (card->capabilities==(MS_SND_CARD_CAP_CAPTURE|MS_SND_CARD_CAP_PLAYBACK))
+			return card;
+	}
 	return NULL;
 }
 
@@ -77,7 +83,7 @@ MSSndCard * ms_snd_card_dup(MSSndCard *card){
 }
 
 MSSndCard * ms_snd_card_new(MSSndCardDesc *desc){
-	MSSndCard *obj=ms_new(MSSndCard,1);
+	MSSndCard *obj=(MSSndCard *)ms_new(MSSndCard,1);
 	obj->desc=desc;
 	obj->name=NULL;
 	obj->data=NULL;
