@@ -17,6 +17,8 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+#ifdef __linux
+
 #include "mediastreamer-config.h"
 
 #include <fcntl.h>
@@ -45,6 +47,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 /* Set enable workaround for bugs, bitfield */
 #define VIDIOCQCSCOMPATIBLE _IOWR('v',QC_IOCTLBASE+10,int)
 
+#ifndef VIDIOSFPS
+#define VIDIOSFPS _IOW('v',BASE_VIDIOCPRIVATE+20, int)
+#endif
 
 typedef struct V4lState{
 	int fd;
@@ -440,24 +445,27 @@ static int v4l_do_mmap(V4lState *s){
 	}
 	s->mmapdbuf=mmap(NULL,s->msize,PROT_READ,MAP_SHARED,s->fd,0);
 	if (s->mmapdbuf==(void*)-1) {
-		ms_error("Could not mmap: %s",strerror(errno));
-		s->mmapdbuf=NULL;
-		return -1;
-	}else {
-		/* initialize the mediastreamer buffers */
-		ms_message("Using %i-frames mmap'd buffer at %p, len %i",
-			s->frame_max, s->mmapdbuf,s->msize);
-		for(i=0;i<s->frame_max;i++){
-			mblk_t *buf=esballoc((uint8_t*)s->mmapdbuf+vmbuf.offsets[i],vmbuf.offsets[1],0,NULL);
-			/* adjust to real size of picture*/
-			if (s->pix_fmt==MS_RGB24)
-				buf->b_wptr+=s->vsize.width*s->vsize.height*3;
-			else 
-				buf->b_wptr+=(s->vsize.width*s->vsize.height*3)/2;
-			s->frames[i]=buf;
+		/* for non-mmu arch */
+		s->mmapdbuf=mmap(NULL,s->msize,PROT_READ,MAP_PRIVATE,s->fd,0);
+		if (s->mmapdbuf==(void*)-1) {
+			ms_error("Could not mmap: %s",strerror(errno));
+			s->mmapdbuf=NULL;
+			return -1;
 		}
-		s->frame_ind=0;
 	}
+	/* initialize the mediastreamer buffers */
+	ms_message("Using %i-frames mmap'd buffer at %p, len %i",
+		s->frame_max, s->mmapdbuf,s->msize);
+	for(i=0;i<s->frame_max;i++){
+		mblk_t *buf=esballoc((uint8_t*)s->mmapdbuf+vmbuf.offsets[i],vmbuf.offsets[1],0,NULL);
+		/* adjust to real size of picture*/
+		if (s->pix_fmt==MS_RGB24)
+			buf->b_wptr+=s->vsize.width*s->vsize.height*3;
+		else 
+			buf->b_wptr+=(s->vsize.width*s->vsize.height*3)/2;
+		s->frames[i]=buf;
+	}
+	s->frame_ind=0;
 	return 0;
 }
 
@@ -501,6 +509,7 @@ static int v4l_configure(V4lState *s)
 	struct video_capability cap;
 	int err;
 	int i;
+	int fps = 0;
 	int found=0;
 	
 	memset(&chan,0,sizeof(chan));
@@ -548,20 +557,25 @@ static int v4l_configure(V4lState *s)
 	}
 	ms_message("Default picture properties: brightness=%i,hue=%i,colour=%i,contrast=%i,depth=%i, palette=%i.",
 						pict.brightness,pict.hue,pict.colour, pict.contrast,pict.depth, pict.palette);
-	/* trying YUV420P format:*/
 	
+	/* trying color format */
 	if (try_format(s->fd,&pict,VIDEO_PALETTE_YUV420P,16)){
 		ms_message("Driver supports YUV420P, using that format.");
 		s->pix_fmt=MS_YUV420P;
-	}else{
-		ms_message("Driver does not support YUV420P, trying RGB24...");
-		if (try_format(s->fd, &pict,VIDEO_PALETTE_RGB24,24)){
-			ms_message("Driver supports RGB24, using that format.");
-			s->pix_fmt=MS_RGB24;
-		}else{
-			ms_fatal("Unsupported video pixel format.");
-		}
+	}else if (try_format(s->fd, &pict,VIDEO_PALETTE_RGB24,24)){
+		ms_message("Driver supports RGB24, using that format.");
+		s->pix_fmt=MS_RGB24;
+	}else if (try_format(s->fd, &pict,VIDEO_PALETTE_YUV422, 16)){
+		ms_message("Driver supports YUV422, using that format.");
+		s->pix_fmt=MS_YUYV;
+	}else if (try_format(s->fd, &pict,VIDEO_PALETTE_UYVY, 16)){
+		ms_message("Driver supports UYVY, using that format.");
+		s->pix_fmt=MS_UYVY;
+	}else{	
+		ms_fatal("Unsupported video pixel format.");
+		return -1;
 	}
+
 	if (!try_size(s,s->vsize)) {
 		if (!try_size(s,MS_VIDEO_SIZE_NS1)){
 			if (!try_size(s,MS_VIDEO_SIZE_VGA)){
@@ -575,6 +589,14 @@ static int v4l_configure(V4lState *s)
 			}
 		}
 	}
+
+	/* Try HW frame rate control */
+	fps = s->fps;
+	if (ioctl(s->fd, VIDIOSFPS, &fps) < 0 )
+		ms_message("v4l_configure: cannot set HW frame rate control");
+	else
+		ms_message("v4l_configure: set HW fps to be : %d", fps);
+	
 	return 0;
 }	
 
@@ -585,6 +607,10 @@ int ms_to_v4l_pix_fmt(MSPixFmt p){
 				return VIDEO_PALETTE_YUV420P;
 		case MS_RGB24:
 				return VIDEO_PALETTE_RGB24;
+		case MS_YUYV:
+				return VIDEO_PALETTE_YUV422;
+		case MS_UYVY:
+				return VIDEO_PALETTE_UYVY;
 		default:
 			ms_fatal("unsupported pix fmt");
 			return -1;
@@ -625,6 +651,8 @@ static void pic_copy(uint8_t *dest, int dw, int dh, uint8_t *src, int sw, int sh
 		plane_copy(dest,dw/2,dh/2,src,sw/2,sh/2,1);
 	}else if (fmt==MS_RGB24){
 		plane_copy(dest,dw,dh,src,sw,sh,3);
+	}else if (fmt==MS_YUYV||fmt==MS_UYVY){
+		plane_copy(dest,dw,dh,src,sw,sh,4);
 	}
 }
 
@@ -632,6 +660,8 @@ static mblk_t *crop_or_pad(V4lState *s, mblk_t *pic){
 	int size=s->vsize.width*s->vsize.height;
 	mblk_t *newpic;
 	if (s->pix_fmt==MS_YUV420P) size=size*3/2;
+	else if (s->pix_fmt==MS_YUYV) size=size*2;
+	else if (s->pix_fmt==MS_UYVY) size=size*2;
 	else if (s->pix_fmt==MS_RGB24) size=size*3;
 	else ms_fatal("crop_or_pad: unsupported pixel format.");
 	newpic=allocb(size,0);
@@ -792,6 +822,7 @@ static void v4l_do_munmap(V4lState *s){
 	}
 }
 
+
 static void *v4l_thread(void *ptr){
 	V4lState *s=(V4lState*)ptr;
 	int err=-1;
@@ -921,3 +952,5 @@ MSFilterDesc ms_v4l_desc={
 };
 
 MS_FILTER_DESC_EXPORT(ms_v4l_desc)
+
+#endif
