@@ -1,6 +1,7 @@
 #include "mediastreamer2/mscommon.h"
 #include "mediastreamer2/msvideo.h"
 
+#include <ffmpeg/swscale.h>
 #include <ffmpeg/avcodec.h>
 
 #ifdef HAVE_CONFIG_H
@@ -23,6 +24,8 @@ static mblk_t *jpeg2yuv(uint8_t *jpgbuf, int bufsize, MSVideoSize *reqsize){
 	AVFrame orig;
 	AVPicture dest;
 	mblk_t *ret;
+	struct SwsContext *sws_ctx;
+
 	avcodec_get_context_defaults(&av_context);
 	if (avcodec_open(&av_context,avcodec_find_decoder(CODEC_ID_MJPEG))<0){
 		ms_error("jpeg2yuv: avcodec_open failed");
@@ -36,14 +39,12 @@ static mblk_t *jpeg2yuv(uint8_t *jpgbuf, int bufsize, MSVideoSize *reqsize){
 	ret=allocb(avpicture_get_size(PIX_FMT_YUV420P,reqsize->width,reqsize->height),0);
 	ret->b_wptr=ret->b_datap->db_lim;
 	avpicture_fill(&dest,ret->b_rptr,PIX_FMT_YUV420P,reqsize->width,reqsize->height);
-	if (reqsize->width==av_context.width && reqsize->height==av_context.height){
-		img_copy(&dest,(AVPicture*)&orig,PIX_FMT_YUV420P,reqsize->width,reqsize->height);
-	}else{
-		ImgReSampleContext *rsctx=img_resample_init(reqsize->width,reqsize->height,
-				av_context.width,av_context.height);
-		img_resample(rsctx,&dest,(AVPicture*)&orig);
-		img_resample_close(rsctx);
-	}
+	
+	sws_ctx=sws_getContext(av_context.width,av_context.height,PIX_FMT_YUV420P,
+		reqsize->width,reqsize->height,PIX_FMT_YUV420P,SWS_FAST_BILINEAR,
+                NULL, NULL, NULL);
+	sws_scale(sws_ctx,orig.data,orig.linesize,0,0,dest.data,dest.linesize);
+	sws_freeContext(sws_ctx);
 	avcodec_close(&av_context);
 	return ret;
 }
