@@ -51,6 +51,7 @@ typedef struct EncState{
 	float fps;
 	int maxbr;
 	int qmin;
+	bool_t req_vfu;
 }EncState;
 
 static int enc_set_fps(MSFilter *f, void *arg){
@@ -85,6 +86,7 @@ static int enc_set_mtu(MSFilter *f,void *arg){
 
 static int enc_set_br(MSFilter *f, void *arg){
 	EncState *s=(EncState*)f->data;
+	bool_t snow=s->codec==CODEC_ID_SNOW;
 	s->maxbr=*(int*)arg;
 	if (s->maxbr>=512000){
 		s->vsize.width=MS_VIDEO_SIZE_CIF_W;
@@ -103,7 +105,12 @@ static int enc_set_br(MSFilter *f, void *arg){
 	}else if (s->maxbr>=64000){
 		s->vsize.width=MS_VIDEO_SIZE_QCIF_W;
 		s->vsize.height=MS_VIDEO_SIZE_QCIF_H;
-		s->fps=6;
+		s->fps=snow ? 7 : 5;
+		s->qmin=snow ? 4 : 5;
+	}else{
+		s->vsize.width=MS_VIDEO_SIZE_QCIF_W;
+		s->vsize.height=MS_VIDEO_SIZE_QCIF_H;
+		s->fps=5;
 		s->qmin=5;
 	}
 	return 0;
@@ -158,9 +165,15 @@ static int enc_add_fmtp(MSFilter *f,void *arg){
 	return 0;
 }
 
+static int enc_req_vfu(MSFilter *f, void *unused){
+	EncState *s=(EncState*)f->data;
+	s->req_vfu=TRUE;
+	return 0;
+}
+
 static void enc_init(MSFilter *f, enum CodecID codec)
 {
-	EncState *s=ms_new(EncState,1);
+	EncState *s=(EncState *)ms_new(EncState,1);
 	f->data=s;
 	ms_ffmpeg_check_init();
 	s->profile=0;/*always default to profile 0*/
@@ -172,6 +185,7 @@ static void enc_init(MSFilter *f, enum CodecID codec)
 	s->vsize.width=MS_VIDEO_SIZE_CIF_W;
 	s->vsize.height=MS_VIDEO_SIZE_CIF_H;
 	s->qmin=2;
+	s->req_vfu=FALSE;
 }
 
 static void enc_h263_init(MSFilter *f){
@@ -182,20 +196,39 @@ static void enc_mpeg4_init(MSFilter *f){
 	enc_init(f,CODEC_ID_MPEG4);
 }
 
+static void enc_snow_init(MSFilter *f){
+	enc_init(f,CODEC_ID_SNOW);
+}
 
 static void prepare(EncState *s){
 	AVCodecContext *c=&s->av_context;
 	avcodec_get_context_defaults(c);
-	ms_message("sizeof(AVCodecContext)=%i",sizeof(AVCodecContext));
 	/* put codec parameters */
-	c->bit_rate=20000;
+	c->bit_rate=(float)s->maxbr*0.9;
+	c->bit_rate_tolerance=s->maxbr/5;
+	if (s->codec!=CODEC_ID_SNOW && s->maxbr<256000){
+		/*snow does not like 1st pass rate control*/
+		/*and rate control eats too much cpu with CIF high fps pictures*/
+		c->rc_max_rate=s->maxbr;
+		c->rc_min_rate=0;
+		c->rc_buffer_size=100000;
+	}else{
+		/*use qmin instead*/
+		c->qmin=s->qmin;
+	}
+
+	ms_message("Codec bitrate set to %i",c->bit_rate);
 	c->width = s->vsize.width;  
 	c->height = s->vsize.height;
-	c->time_base.num = (int)s->fps;
-	c->time_base.den = 1;
+	c->time_base.num = 1;
+	c->time_base.den = (int)s->fps;
 	c->gop_size=(int)s->fps*5; /*emit I frame every 5 seconds*/
 	c->pix_fmt=PIX_FMT_YUV420P;
-	c->qmin=s->qmin;
+	
+	if (s->codec==CODEC_ID_SNOW){
+		c->strict_std_compliance=-2;
+	}
+	
 }
 
 static void prepare_h263(EncState *s){
@@ -220,10 +253,10 @@ static void prepare_h263(EncState *s){
 
 static void prepare_mpeg4(EncState *s){
 	AVCodecContext *c=&s->av_context;
-	c->flags|=CODEC_FLAG_LOW_DELAY;	/*don't use b frames ?*/
+	c->max_b_frames=0; /*don't use b frames*/
 	c->flags|=CODEC_FLAG_AC_PRED;
 	c->flags|=CODEC_FLAG_H263P_UMV;
-	c->flags|=CODEC_FLAG_QPEL;
+	/*c->flags|=CODEC_FLAG_QPEL;*/ /*don't enable this one: this forces profile_level to advanced simple profile */
 	c->flags|=CODEC_FLAG_4MV;
 	c->flags|=CODEC_FLAG_GMC;
 	c->flags|=CODEC_FLAG_LOOP_FILTER;
@@ -253,7 +286,9 @@ static void enc_preprocess(MSFilter *f){
 		prepare_h263(s);
 	else if (s->codec==CODEC_ID_MPEG4)
 		prepare_mpeg4(s);
-	else{
+	else if (s->codec==CODEC_ID_SNOW){
+		/**/
+	}else {
 		ms_error("Unsupported codec id %i",s->codec);
 		return;
 	}
@@ -358,7 +393,7 @@ static void split_and_send(MSFilter *f, EncState *s, mblk_t *frame){
 	uint8_t *psc;
 	uint32_t timestamp=f->ticker->time*90LL;
 	
-	if (s->codec==CODEC_ID_MPEG4)
+	if (s->codec==CODEC_ID_MPEG4 || s->codec==CODEC_ID_SNOW)
 	{
 		mpeg4_fragment_and_send(f,s,frame,timestamp);
 		return;
@@ -383,19 +418,33 @@ static void process_frame(MSFilter *f, mblk_t *inm){
 	AVFrame pict;
 	AVCodecContext *c=&s->av_context;
 	int error;
-	
 	mblk_t *comp_buf=s->comp_buf;
 	int comp_buf_sz=comp_buf->b_datap->db_lim-comp_buf->b_datap->db_base;
+	
 	/* convert image if necessary */
 	avcodec_get_frame_defaults(&pict);
 	avpicture_fill((AVPicture*)&pict,(uint8_t*)inm->b_rptr,c->pix_fmt,c->width,c->height);
 	
 	/* timestamp used by ffmpeg, unset here */
 	pict.pts=AV_NOPTS_VALUE;
+	if (s->req_vfu){
+		pict.pict_type=FF_I_TYPE;
+		s->req_vfu=FALSE;
+	}
 	comp_buf->b_rptr=comp_buf->b_wptr=comp_buf->b_datap->db_base;
-	error=avcodec_encode_video(c, (uint8_t*)s->comp_buf->b_wptr,comp_buf_sz, &pict);
+	if (s->codec==CODEC_ID_SNOW){
+		//prepend picture size
+		uint32_t header=((s->vsize.width&0xffff)<<16) | (s->vsize.height&0xffff);
+		*(uint32_t*)comp_buf->b_wptr=htonl(header);
+		comp_buf->b_wptr+=4;
+		comp_buf_sz-=4;
+	}
+	error=avcodec_encode_video(c, (uint8_t*)comp_buf->b_wptr,comp_buf_sz, &pict);
 	if (error<=0) ms_warning("ms_AVencoder_process: error %i.",error);
 	else{
+		if (c->coded_frame->pict_type==FF_I_TYPE){
+			ms_message("Emitting I-frame");
+		}
 		comp_buf->b_wptr+=error;
 		split_and_send(f,s,comp_buf);
 	}
@@ -422,6 +471,7 @@ static MSFilterMethod methods[]={
 	{	MS_FILTER_ADD_FMTP	,	enc_add_fmtp },
 	{	MS_FILTER_SET_BITRATE	,	enc_set_br	},
 	{	MS_FILTER_SET_MTU	,	enc_set_mtu	},
+	{	MS_FILTER_REQ_VFU	,	enc_req_vfu	},
 	{	0			,	NULL	}
 };
 
@@ -459,6 +509,22 @@ MSFilterDesc ms_mpeg4_enc_desc={
 	methods
 };
 
+MSFilterDesc ms_snow_enc_desc={
+	MS_SNOW_ENC_ID,
+	"MSSnowEnc",
+	"A video snow encoder using ffmpeg library.",
+	MS_FILTER_ENCODER,
+	"x-snow",
+	1, /*MS_YUV420P is assumed on this input */
+	1,
+	enc_snow_init,
+	enc_preprocess,
+	enc_process,
+	enc_postprocess,
+	enc_uninit,
+	methods
+};
+
 #else
 
 MSFilterDesc ms_h263_enc_desc={
@@ -493,8 +559,45 @@ MSFilterDesc ms_mpeg4_enc_desc={
 	.methods=methods
 };
 
+MSFilterDesc ms_snow_enc_desc={
+	.id=MS_SNOW_ENC_ID,
+	.name="MSSnowEnc",
+	.text="The snow codec is royalty-free and is open-source. \n"
+		"It uses innovative techniques that makes it one of the best video "
+		"codec. It is implemented within the ffmpeg project.\n"
+		"However it is under development and compatibility with other versions "
+		"cannot be guaranteed.",
+	.category=MS_FILTER_ENCODER,
+	.enc_fmt="x-snow",
+	.ninputs=1, /*MS_YUV420P is assumed on this input */
+	.noutputs=1,
+	.init=enc_snow_init,
+	.preprocess=enc_preprocess,
+	.process=enc_process,
+	.postprocess=enc_postprocess,
+	.uninit=enc_uninit,
+	.methods=methods
+};
+
 #endif
 
+#if defined(WIN32) || defined(_WIN32_WCE)
+__declspec(dllexport) PayloadType payload_type_x_snow
+#else
+PayloadType payload_type_x_snow
+#endif
+={
+	PAYLOAD_VIDEO,
+	90000,
+	0,
+	NULL,
+	0,
+	256000,
+	"x-snow"
+};
+
+
 MS_FILTER_DESC_EXPORT(ms_mpeg4_enc_desc)
 MS_FILTER_DESC_EXPORT(ms_h263_enc_desc)
+MS_FILTER_DESC_EXPORT(ms_snow_enc_desc)
 
