@@ -367,12 +367,13 @@ int video_stream_send_only_start(VideoStream* stream, RtpProfile *profile, const
 }
 
 void video_stream_send_only_stop(VideoStream *stream){
-	ms_ticker_detach (stream->ticker, stream->source);
-	ms_filter_call_method_noarg(stream->source,MS_V4L_STOP);
-	ms_filter_unlink(stream->source,0,stream->pixconv,0);
-	ms_filter_unlink(stream->pixconv,0,stream->encoder,0);
-	ms_filter_unlink(stream->encoder,0,stream->rtpsend,0);
-	
+	if (stream->ticker){
+		ms_ticker_detach (stream->ticker, stream->source);
+		ms_filter_call_method_noarg(stream->source,MS_V4L_STOP);
+		ms_filter_unlink(stream->source,0,stream->pixconv,0);
+		ms_filter_unlink(stream->pixconv,0,stream->encoder,0);
+		ms_filter_unlink(stream->encoder,0,stream->rtpsend,0);
+	}
 	video_stream_free(stream);
 }
 
@@ -442,11 +443,13 @@ int video_stream_recv_only_start (VideoStream *stream, RtpProfile *profile, cons
 }
 
 void video_stream_recv_only_stop (VideoStream * stream){
-	ms_ticker_detach(stream->ticker, stream->rtprecv);
-	rtp_stats_display(rtp_session_get_stats(stream->session),"Video session's RTP statistics");
-	ms_filter_unlink(stream->rtprecv, 0, stream->decoder, 0);
-	ms_filter_unlink(stream->decoder,0,stream->sizeconv,0);
-	ms_filter_unlink(stream->sizeconv,0,stream->output,0);
+	if (stream->ticker!=NULL){
+		ms_ticker_detach(stream->ticker, stream->rtprecv);
+		rtp_stats_display(rtp_session_get_stats(stream->session),"Video session's RTP statistics");
+		ms_filter_unlink(stream->rtprecv, 0, stream->decoder, 0);
+		ms_filter_unlink(stream->decoder,0,stream->sizeconv,0);
+		ms_filter_unlink(stream->sizeconv,0,stream->output,0);
+	}
 	video_stream_free (stream);
 }
 
