@@ -434,7 +434,7 @@ static void winsnd_set_source(MSSndCard *card, MSSndCardCapture source)
 }
 
 static void winsnd_init(MSSndCard *card){
-	WinSndData *d=ms_new(WinSndData,1);
+	WinSndData *d=(WinSndData*)ms_new(WinSndData,1);
     memset(d, 0, sizeof(WinSndData));
 	d->bytes_read=0;
 	d->pcmdev=NULL;
