@@ -30,6 +30,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "vfw-missing.h"
 #endif
 
+#define AMD_HACK2
+
 typedef struct V4wState{
 #ifdef AMD_HACK2
 	ms_thread_t thread;
@@ -210,7 +212,7 @@ static int v4w_open_videodevice(V4wState *s)
 }
 
 static void v4w_init(MSFilter *f){
-	V4wState *s=ms_new0(V4wState,1);
+	V4wState *s=(V4wState *)ms_new0(V4wState,1);
 	int idx;
 	s->vsize.width=MS_VIDEO_SIZE_CIF_W;
 	s->vsize.height=MS_VIDEO_SIZE_CIF_H;
@@ -330,8 +332,9 @@ v4w_thread(void *arg)
 		{
 		  TranslateMessage(&msg); 
 		  DispatchMessage(&msg);
-		} 
-		Sleep(100);
+		}
+		else
+			Sleep(10);
 	}
 
 	ms_mutex_lock(&s->thread_lock);
@@ -457,6 +460,8 @@ static void v4w_process(MSFilter * obj){
 		s->start_time=obj->ticker->time;
 		s->frame_count=0;
 	}
+
+
 	cur_frame=((obj->ticker->time-s->start_time)*s->fps/1000.0);
 	if (cur_frame>s->frame_count){
 		mblk_t *om=NULL;
@@ -491,7 +496,7 @@ static int v4w_set_fps(MSFilter *f, void *arg){
 
 static int v4w_get_pix_fmt(MSFilter *f,void *arg){
 	V4wState *s=(V4wState*)f->data;
-	*((MSPixFmt*)arg) = s->pix_fmt;
+	*((MSPixFmt*)arg) = (MSPixFmt)s->pix_fmt;
 	return 0;
 }
 
