@@ -118,6 +118,11 @@ const char *usage="mediastream --local <port> --remote <ip:port> --payload <payl
 								"[ --jitter <miliseconds>]\n";
 static void run_media_streams(int localport, const char *remote_ip, int remoteport, int payload, const char *fmtp, int jitter, bool_t ec, int bitrate);
 
+
+#ifdef VIDEO_ENABLED
+VAR_DECLSPEC PayloadType payload_type_x_snow;
+#endif
+
 int main(int argc, char * argv[])
 {
 	int i;
@@ -134,9 +139,12 @@ int main(int argc, char * argv[])
 	rtp_profile_set_payload(&av_profile,110,&payload_type_speex_nb);
 	rtp_profile_set_payload(&av_profile,111,&payload_type_speex_wb);
 	rtp_profile_set_payload(&av_profile,112,&payload_type_ilbc);
+#ifdef VIDEO_ENABLED
 	rtp_profile_set_payload(&av_profile,98,&payload_type_h263_1998);
 	rtp_profile_set_payload(&av_profile,97,&payload_type_theora);
 	rtp_profile_set_payload(&av_profile,99,&payload_type_mp4v);
+	rtp_profile_set_payload(&av_profile,100,&payload_type_x_snow);
+#endif
 	if (argc<4) {
 		printf(usage);
 		return -1;
