@@ -17,35 +17,23 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#include "msfilter.h"
-#include "msvideo.h"
-#include "msticker.h"
-#include "msv4l.h"
+#include "mediastreamer2/mediastream.h"
 
 int main(int argc, char *argv[]){
-	MSTicker *ticker;
-	MSFilter *grabber;
-	MSFilter *display;
-	MSPixFmt fmt;
-	
+	VideoStream *vs;
+	const char *devname="/dev/video0";
+	int i;
 	ms_init();
-	ticker=ms_ticker_new();
-	grabber=ms_filter_new(MS_V4L_ID);
-	display=ms_filter_new(MS_SDL_OUT_ID);
-	
-	ms_filter_call_method_noarg(grabber,MS_V4L_START);
-	ms_filter_call_method(grabber,MS_FILTER_GET_PIX_FMT,&fmt);
-	ms_filter_call_method(display,MS_FILTER_SET_PIX_FMT,&fmt);
-	
-	ms_filter_link(grabber,0,display,0);
-	ms_ticker_attach(ticker,grabber);
-	sleep(5);
-	ms_ticker_detach(ticker,grabber);
-	
-	ms_filter_call_method_noarg(grabber,MS_V4L_STOP);
-	
-	ms_filter_destroy(grabber);
-	ms_filter_destroy(display);
-	ms_ticker_destroy(ticker);
+
+	/* this is to test the sequence start/stop */
+	for(i=0;i<1;++i){
+		vs=video_preview_start(devname);
+#ifdef WIN32
+		Sleep(5000);
+#else
+		sleep(5);
+#endif
+		video_preview_stop(vs);
+	}
 	return 0;
 }
