@@ -62,6 +62,19 @@ typedef pthread_t ortp_thread_t;
 typedef pthread_mutex_t ortp_mutex_t;
 typedef pthread_cond_t ortp_cond_t;
 
+#ifdef __INTEL_COMPILER
+#pragma warning(disable : 111)		// statement is unreachable
+#pragma warning(disable : 181)		// argument is incompatible with corresponding format string conversion
+#pragma warning(disable : 188)		// enumerated type mixed with another type
+#pragma warning(disable : 593)		// variable "xxx" was set but never used
+#pragma warning(disable : 810)		// conversion from "int" to "unsigned short" may lose significant bits
+#pragma warning(disable : 869)		// parameter "xxx" was never referenced
+#pragma warning(disable : 981)		// operands are evaluated in unspecified order
+#pragma warning(disable : 1418)		// external function definition with no prior declaration
+#pragma warning(disable : 1419)		// external declaration in primary source file
+#pragma warning(disable : 1469)		// "cc" clobber ignored
+#endif
+
 int __ortp_thread_join(ortp_thread_t thread, void **ptr);
 
 #define ortp_thread_create	pthread_create
@@ -135,6 +148,12 @@ typedef HANDLE ortp_thread_t;
 #define ortp_cond_wait		WIN_cond_wait
 #define ortp_cond_destroy	WIN_cond_destroy
 
+
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+	
 int WIN_mutex_init(ortp_mutex_t *m, void *attr_unused);
 int WIN_mutex_lock(ortp_mutex_t *mutex);
 int WIN_mutex_unlock(ortp_mutex_t *mutex);
@@ -147,6 +166,9 @@ int WIN_cond_signal(ortp_cond_t * cond);
 int WIN_cond_broadcast(ortp_cond_t * cond);
 int WIN_cond_destroy(ortp_cond_t * cond);
 
+#ifdef __cplusplus
+}
+#endif
 
 #define SOCKET_OPTION_VALUE	char *
 #define inline			__inline
