@@ -77,6 +77,11 @@
 #include <ortp/stun_udp.h>
 
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 /* if you change this version, change in makefile too  */
 #define STUN_VERSION "0.94"
 
@@ -201,48 +206,48 @@ typedef struct
 {
       StunMsgHdr msgHdr;
 	
-      bool hasMappedAddress;
+      bool_t hasMappedAddress;
       StunAtrAddress4  mappedAddress;
 	
-      bool hasResponseAddress;
+      bool_t hasResponseAddress;
       StunAtrAddress4  responseAddress;
 	
-      bool hasChangeRequest;
+      bool_t hasChangeRequest;
       StunAtrChangeRequest changeRequest;
 	
-      bool hasSourceAddress;
+      bool_t hasSourceAddress;
       StunAtrAddress4 sourceAddress;
 	
-      bool hasChangedAddress;
+      bool_t hasChangedAddress;
       StunAtrAddress4 changedAddress;
 	
-      bool hasUsername;
+      bool_t hasUsername;
       StunAtrString username;
 	
-      bool hasPassword;
+      bool_t hasPassword;
       StunAtrString password;
 	
-      bool hasMessageIntegrity;
+      bool_t hasMessageIntegrity;
       StunAtrIntegrity messageIntegrity;
 	
-      bool hasErrorCode;
+      bool_t hasErrorCode;
       StunAtrError errorCode;
 	
-      bool hasUnknownAttributes;
+      bool_t hasUnknownAttributes;
       StunAtrUnknown unknownAttributes;
 	
-      bool hasReflectedFrom;
+      bool_t hasReflectedFrom;
       StunAtrAddress4 reflectedFrom;
 
-      bool hasXorMappedAddress;
+      bool_t hasXorMappedAddress;
       StunAtrAddress4  xorMappedAddress;
 	
-      bool xorOnly;
+      bool_t xorOnly;
 
-      bool hasServerName;
+      bool_t hasServerName;
       StunAtrString serverName;
       
-      bool hasSecondaryAddress;
+      bool_t hasSecondaryAddress;
       StunAtrAddress4 secondaryAddress;
 } StunMessage; 
 
@@ -282,27 +287,27 @@ typedef struct
       Socket altPortFd;
       Socket altIpFd;
       Socket altIpPortFd;
-      bool relay; /* true if media relaying is to be done */
+      bool_t relay; /* true if media relaying is to be done */
       StunMediaRelay relays[MAX_MEDIA_RELAYS];
 } StunServerInfo;
 
-bool
+bool_t
 stunParseMessage( char* buf, 
                   unsigned int bufLen, 
                   StunMessage *message, 
-                  bool verbose );
+                  bool_t verbose );
 
 void
 stunBuildReqSimple( StunMessage* msg,
                     const StunAtrString *username,
-                    bool changePort, bool changeIp, unsigned int id );
+                    bool_t changePort, bool_t changeIp, unsigned int id );
 
 unsigned int
 stunEncodeMessage( const StunMessage *message, 
                    char* buf, 
                    unsigned int bufLen, 
                    const StunAtrString *password,
-                   bool verbose);
+                   bool_t verbose);
 
 void
 stunCreateUserName(const StunAddress4 *addr, StunAtrString* username);
@@ -322,10 +327,10 @@ UInt64
 stunGetSystemTimeSecs(void);
 
 /* find the IP address of a the specified stun server - return false is fails parse  */
-bool  
+bool_t  
 stunParseServerName( char* serverName, StunAddress4 *stunServerAddr);
 
-bool 
+bool_t 
 stunParseHostName( char* peerName,
                    UInt32 *ip,
                    UInt16 *portVal,
@@ -333,20 +338,20 @@ stunParseHostName( char* peerName,
 
 /* return true if all is OK 
    Create a media relay and do the STERN thing if startMediaPort is non-zero */
-bool
+bool_t
 stunInitServer(StunServerInfo *info, 
                const StunAddress4 *myAddr, 
                const StunAddress4 *altAddr,
                int startMediaPort,
-               bool verbose);
+               bool_t verbose);
 
 void
 stunStopServer(StunServerInfo *info);
 
 #if 0 /* no usefull here */
 /* return true if all is OK */
-bool
-stunServerProcess(StunServerInfo *info, bool verbose);
+bool_t
+stunServerProcess(StunServerInfo *info, bool_t verbose);
 #endif
 
 /* returns number of address found - take array or addres */
@@ -354,17 +359,17 @@ int
 stunFindLocalInterfaces(UInt32* addresses, int maxSize );
 
 int 
-stunTest( StunAddress4 *dest, int testNum, bool verbose, StunAddress4* srcAddr, StunAddress4 *sMappedAddr, StunAddress4* sChangedAddr);
+stunTest( StunAddress4 *dest, int testNum, bool_t verbose, StunAddress4* srcAddr, StunAddress4 *sMappedAddr, StunAddress4* sChangedAddr);
 
 NatType
-stunNatType( StunAddress4 *dest, bool verbose, 
-             bool* preservePort, /* if set, is return for if NAT preservers ports or not */
-             bool* hairpin ,  /* if set, is the return for if NAT will hairpin packets */
+stunNatType( StunAddress4 *dest, bool_t verbose, 
+             bool_t* preservePort, /* if set, is return for if NAT preservers ports or not */
+             bool_t* hairpin ,  /* if set, is the return for if NAT will hairpin packets */
              int port, /* port to use for the test, 0 to choose random port */
              StunAddress4* sAddr /* NIC to use */
    );
 
-bool
+bool_t
 stunServerProcessMsg( char* buf,
                       unsigned int bufLen,
                       StunAddress4 *from, 
@@ -374,32 +379,28 @@ stunServerProcessMsg( char* buf,
                       StunMessage *resp,
                       StunAddress4 *destination,
                       StunAtrString *hmacPassword,
-                      bool* changePort,
-                      bool* changeIp,
-                      bool verbose);
+                      bool_t* changePort,
+                      bool_t* changeIp,
+                      bool_t verbose);
 
 int
 stunOpenSocket( StunAddress4 *dest, 
                 StunAddress4* mappedAddr, 
                 int port, 
                 StunAddress4* srcAddr, 
-                bool verbose );
+                bool_t verbose );
 
-bool
+bool_t
 stunOpenSocketPair(StunAddress4 *dest,
                    StunAddress4* mapAddr_rtp, 
                    StunAddress4* mapAddr_rtcp, 
                    int* fd1, int* fd2, 
                    int srcPort,  StunAddress4* srcAddr,
-                   bool verbose);
+                   bool_t verbose);
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif
 
-/* Local Variables:
-   mode:c
-   c-file-style:"ellemtel"
-   c-file-offsets:((case-label . +))
-   indent-tabs-mode:nil
-   End:
-*/
-
