@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -22,34 +22,47 @@
 
 char offset127=127; 
 char offset0xD5=(char)0xD5; 
-char offset0=0;
-
-/* IMPORTANT */
-/* some compiler don't support the "field:" syntax. Those macros are there to trap the problem
-This means that if you want to keep portability, payload types must be defined with their fields
-in the right order. */
-
-#if !defined(__hpux) && !defined(WIN32) 
-
-#define TYPE(val) type: (val)
-#define CLOCK_RATE(val) clock_rate: (val)
-#define BITS_PER_SAMPLE(val) bits_per_sample: (val)
-#define ZERO_PATTERN(val)   zero_pattern: (val)
-#define PATTERN_LENGTH(val) pattern_length: (val)
-#define NORMAL_BITRATE(val) normal_bitrate: (val)
-#define MIME_TYPE(val) mime_type: (val)
-#define FMTP(val) FMTP : (val)
+char offset0[4] = {0x00, 0x00, 0x00, 0x00};
 
+/* 
+ * IMPORTANT : some compiler don't support the tagged-field syntax. Those
+ * macros are there to trap the problem This means that if you want to keep
+ * portability, payload types must be defined with their fields in the right
+ * order.
+ */
+#if defined(_ISOC99_SOURCE)
+// ISO C99's tagged syntax
+#define TYPE(val)		.type=(val)
+#define CLOCK_RATE(val)		.clock_rate=(val)
+#define BITS_PER_SAMPLE(val)	.bits_per_sample=(val)
+#define ZERO_PATTERN(val)	.zero_pattern=(val)
+#define PATTERN_LENGTH(val)	.pattern_length=(val)
+#define NORMAL_BITRATE(val)	.normal_bitrate=(val)
+#define MIME_TYPE(val)		.mime_type=(val)
+#define CHANNELS(val)		.channels=(val)
+#define FMTP(val)		.FMTP=(val)
+#elif defined(__GNUC__)
+// GCC's legacy tagged syntax (even old versions have it)
+#define TYPE(val)		type: (val)
+#define CLOCK_RATE(val)		clock_rate: (val)
+#define BITS_PER_SAMPLE(val)	bits_per_sample: (val)
+#define ZERO_PATTERN(val)	zero_pattern: (val)
+#define PATTERN_LENGTH(val)	pattern_length: (val)
+#define NORMAL_BITRATE(val)	normal_bitrate: (val)
+#define MIME_TYPE(val)		mime_type: (val)
+#define CHANNELS(val)		channels: (val)
+#define FMTP(val)		FMTP: (val)
 #else
-
-#define TYPE(val) (val)
-#define CLOCK_RATE(val) (val)
-#define BITS_PER_SAMPLE(val) (val)
-#define ZERO_PATTERN(val) (val)
-#define PATTERN_LENGTH(val) (val)
-#define NORMAL_BITRATE(val) (val)
-#define MIME_TYPE(val) (val)
-#define FMTP(val)	(val)
+// No tagged syntax supported
+#define TYPE(val)		(val)
+#define CLOCK_RATE(val)		(val)
+#define BITS_PER_SAMPLE(val)	(val)
+#define ZERO_PATTERN(val)	(val)
+#define PATTERN_LENGTH(val)	(val)
+#define NORMAL_BITRATE(val)	(val)
+#define MIME_TYPE(val)		(val)
+#define CHANNELS(val)		(val)
+#define FMTP(val)		(val)
 
 #endif
 
@@ -60,7 +73,8 @@ PayloadType payload_type_pcmu8000={
 	ZERO_PATTERN( &offset127),
 	PATTERN_LENGTH( 1),
 	NORMAL_BITRATE( 64000),
-	MIME_TYPE ("PCMU")
+	MIME_TYPE ("PCMU"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_pcma8000={
@@ -70,17 +84,41 @@ PayloadType payload_type_pcma8000={
 	ZERO_PATTERN( &offset0xD5),
 	PATTERN_LENGTH( 1),
 	NORMAL_BITRATE( 64000),
-	MIME_TYPE ("PCMA")
+	MIME_TYPE ("PCMA"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_pcm8000={
 	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
 	CLOCK_RATE(8000),
 	BITS_PER_SAMPLE(16),
-	ZERO_PATTERN( &offset0),
+	ZERO_PATTERN( offset0),
 	PATTERN_LENGTH(1),
 	NORMAL_BITRATE( 128000),
-	MIME_TYPE ("PCM")
+	MIME_TYPE ("PCM"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_l16_mono={
+	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
+	CLOCK_RATE(44100),
+	BITS_PER_SAMPLE(16),
+	ZERO_PATTERN( offset0 ),
+	PATTERN_LENGTH(2),
+	NORMAL_BITRATE(705600),				/* (44100 x 16bits per frame x 1 channel) */
+	MIME_TYPE ("L16"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_l16_stereo={
+	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
+	CLOCK_RATE(44100),
+	BITS_PER_SAMPLE(32),				/* 16bits x 2 channels */
+	ZERO_PATTERN( offset0 ),
+	PATTERN_LENGTH(4),
+	NORMAL_BITRATE(1411200),			/* (44100 x 16bits per frame x 2 channels) */
+	MIME_TYPE ("L16"),
+	CHANNELS(2)
 };
 
 PayloadType payload_type_lpc1016={
@@ -90,7 +128,8 @@ PayloadType payload_type_lpc1016={
 	ZERO_PATTERN( NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE( 2400),
-	MIME_TYPE ("1016")
+	MIME_TYPE ("1016"),
+	CHANNELS(1)
 };
 
 
@@ -102,7 +141,20 @@ PayloadType payload_type_gsm=
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE( 13500),
-	MIME_TYPE ("GSM")
+	MIME_TYPE ("GSM"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_lpc=
+{
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 5600),		/* 20ms / 14 octets per frame */
+	MIME_TYPE ("LPC"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_g7231=
@@ -113,7 +165,8 @@ PayloadType payload_type_g7231=
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE( 6300),
-	MIME_TYPE ("G723")
+	MIME_TYPE ("G723"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_g729={
@@ -123,7 +176,8 @@ PayloadType payload_type_g729={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("G729")
+	MIME_TYPE ("G729"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_mpv=
@@ -134,7 +188,8 @@ PayloadType payload_type_mpv=
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE( 256000),
-	MIME_TYPE ("MPV")
+	MIME_TYPE ("MPV"),
+	CHANNELS(0)
 };
 
 
@@ -145,7 +200,8 @@ PayloadType payload_type_h261={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("H261")
+	MIME_TYPE ("H261"),
+	CHANNELS(0)
 };
 
 PayloadType payload_type_h263={
@@ -155,7 +211,8 @@ PayloadType payload_type_h263={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("H263")
+	MIME_TYPE ("H263"),
+	CHANNELS(0)
 };
 
 PayloadType payload_type_truespeech=
@@ -166,7 +223,8 @@ PayloadType payload_type_truespeech=
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE(8536),
-	MIME_TYPE ("TSP0")
+	MIME_TYPE ("TSP0"),
+	CHANNELS(0)
 };
 
 
@@ -183,12 +241,15 @@ RtpProfile av_profile;
 void av_profile_init(RtpProfile *profile)
 {
 	rtp_profile_clear_all(profile);
-	rtp_profile_set_name(profile,"AV profile");
+	profile->name="AV profile";
 	rtp_profile_set_payload(profile,0,&payload_type_pcmu8000);
 	rtp_profile_set_payload(profile,1,&payload_type_lpc1016);
 	rtp_profile_set_payload(profile,3,&payload_type_gsm);
+	rtp_profile_set_payload(profile,7,&payload_type_lpc);
 	rtp_profile_set_payload(profile,4,&payload_type_g7231);
 	rtp_profile_set_payload(profile,8,&payload_type_pcma8000);
+	rtp_profile_set_payload(profile,10,&payload_type_l16_stereo);
+	rtp_profile_set_payload(profile,11,&payload_type_l16_mono);
 	rtp_profile_set_payload(profile,18,&payload_type_g729);
 	rtp_profile_set_payload(profile,31,&payload_type_h261);
 	rtp_profile_set_payload(profile,32,&payload_type_mpv);
@@ -197,43 +258,47 @@ void av_profile_init(RtpProfile *profile)
 	
 /* these are extra payload types that can be used dynamically */
 PayloadType payload_type_lpc1015={
-    TYPE( PAYLOAD_AUDIO_PACKETIZED),
-    CLOCK_RATE(8000),
-    BITS_PER_SAMPLE(0),
-    ZERO_PATTERN(NULL),
-    PATTERN_LENGTH(0),
-    NORMAL_BITRATE(2400),
-    MIME_TYPE ("1015")
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(2400),
+	MIME_TYPE ("1015"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_speex_nb={
-    TYPE( PAYLOAD_AUDIO_PACKETIZED),
-    CLOCK_RATE(8000),
-    BITS_PER_SAMPLE(0),
-    ZERO_PATTERN(NULL),
-    PATTERN_LENGTH(0),
-    NORMAL_BITRATE(8000),   /*not true: 8000 is the minimum*/
-    MIME_TYPE ("speex")
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(8000),   /*not true: 8000 is the minimum*/
+	MIME_TYPE ("speex"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_speex_wb={
-    TYPE( PAYLOAD_AUDIO_PACKETIZED),
-    CLOCK_RATE(16000),
-    BITS_PER_SAMPLE(0),
-    ZERO_PATTERN(NULL),
-    PATTERN_LENGTH(0),
-    NORMAL_BITRATE(28000),
-    MIME_TYPE ("speex")
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(16000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(28000),
+	MIME_TYPE ("speex"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_ilbc={
-	 TYPE( PAYLOAD_AUDIO_PACKETIZED),
-    CLOCK_RATE(8000),
-    BITS_PER_SAMPLE(0),
-    ZERO_PATTERN(NULL),
-    PATTERN_LENGTH(0),
-    NORMAL_BITRATE(13300), /* the minimum, with 30ms frames */ 
-    MIME_TYPE ("iLBC"),
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(13300), /* the minimum, with 30ms frames */ 
+	MIME_TYPE ("iLBC"),
+	CHANNELS(1),
 };
 
 PayloadType payload_type_amr={
@@ -243,7 +308,8 @@ PayloadType payload_type_amr={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("AMR")
+	MIME_TYPE ("AMR"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_amrwb={
@@ -253,7 +319,8 @@ PayloadType payload_type_amrwb={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("AMR-WB")
+	MIME_TYPE ("AMR-WB"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_mp4v={
@@ -263,10 +330,23 @@ PayloadType payload_type_mp4v={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("MP4V-ES")
+	MIME_TYPE ("MP4V-ES"),
+	CHANNELS(0)
 };
-    
-    
+
+
+PayloadType payload_type_evrc0={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(0),
+	MIME_TYPE ("EVRC0"),
+	CHANNELS(1)
+};
+
+ 
 PayloadType payload_type_h263_1998={
 	TYPE( PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
@@ -274,7 +354,8 @@ PayloadType payload_type_h263_1998={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("H263-1998")
+	MIME_TYPE ("H263-1998"),
+	CHANNELS(0)
 };
 
 PayloadType payload_type_h263_2000={
@@ -284,5 +365,21 @@ PayloadType payload_type_h263_2000={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("H263-2000")
+	MIME_TYPE ("H263-2000"),
+	CHANNELS(0)
 };
+
+PayloadType payload_type_theora={
+	TYPE( PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(256000),
+	MIME_TYPE ("theora"),
+	CHANNELS(0)
+};
+
+
+
+
