@@ -28,6 +28,7 @@
 #include "ortp/payloadtype.h"
 #include "ortp/ortp.h"
 #include "utils.h"
+#include "rtpsession_priv.h"
 #include <math.h>
 
 #define JC_BETA 0.03	/*allows a clock slide around 3% */
@@ -127,8 +128,8 @@ void
 rtp_session_set_jitter_compensation (RtpSession * session, int milisec)
 {
 	PayloadType *payload=NULL;
-	if (session->recv_pt!=-1) {
-		payload = rtp_profile_get_payload (session->profile,session->recv_pt);
+	if (session->rcv.pt!=-1) {
+		payload = rtp_profile_get_payload (session->rcv.profile,session->rcv.pt);
 	}/*else not set yet */
 	jitter_control_init(&session->rtp.jittctl,milisec,payload);
 }
@@ -140,3 +141,27 @@ void rtp_session_enable_adaptive_jitter_compensation(RtpSession *session, bool_t
 bool_t rtp_session_adaptive_jitter_compensation_enabled(RtpSession *session){
 	return session->rtp.jittctl.adaptive;
 }
+
+void rtp_session_enable_jitter_buffer(RtpSession *session, bool_t enabled){
+	session->rtp.jittctl.enabled=enabled;
+	session->flags|=RTP_SESSION_RECV_SYNC;
+}
+
+bool_t rtp_session_jitter_buffer_enabled(const RtpSession *session){
+	return session->rtp.jittctl.enabled;
+}
+
+void rtp_session_set_jitter_buffer_params(RtpSession *session, const JBParameters *par){
+	/* FIXME min_size and max_size to be implemented */
+	rtp_session_set_jitter_compensation(session,par->nom_size);
+	jitter_control_enable_adaptive(&session->rtp.jittctl,par->adaptive);
+}
+
+void rtp_session_get_jitter_buffer_params(RtpSession *session, JBParameters *par){
+	int nom_size=session->rtp.jittctl.jitt_comp;
+	par->min_size=nom_size;
+	par->nom_size=nom_size;
+	par->max_size=-1;
+	par->adaptive=session->rtp.jittctl.adaptive;
+}
+
