@@ -23,7 +23,7 @@
 #include "ortp/ortp.h"
 #include "utils.h"
 
-#ifdef _WIN32
+#if	defined(_WIN32) && !defined(_WIN32_WCE)
 #include <process.h>
 #endif
 
@@ -42,7 +42,7 @@ void * ortp_malloc0(size_t size){
 }
 
 char * ortp_strdup(const char *tmp){
-#ifdef WIN32
+#if	defined(_WIN32) || defined(_WIN32_WCE)
     return _strdup(tmp);
 #else
     return strdup(tmp);
@@ -63,7 +63,7 @@ int set_non_blocking_socket (ortp_socket_t sock)
 {
 	
 
-#ifndef _WIN32
+#if	!defined(_WIN32) && !defined(_WIN32_WCE)
 	return fcntl (sock, F_SETFL, O_NONBLOCK);
 #else
 	unsigned long nonBlock = 1;
@@ -78,7 +78,7 @@ int set_non_blocking_socket (ortp_socket_t sock)
  * int retrun the result of the system method
  */
 int close_socket(ortp_socket_t sock){
-#ifndef _WIN32
+#if	!defined(_WIN32) && !defined(_WIN32_WCE)
 	return close (sock);
 #else
 	return closesocket(sock);
@@ -87,7 +87,7 @@ int close_socket(ortp_socket_t sock){
 
 
 
-#ifndef _WIN32
+#if	!defined(_WIN32) && !defined(_WIN32_WCE)
 	/* Use UNIX inet_aton method */
 #else
 	int inet_aton (const char * cp, struct in_addr * addr)
@@ -116,7 +116,7 @@ char *ortp_strndup(const char *str,int n){
 	return ret;
 }
 
-#ifndef _WIN32
+#if	!defined(_WIN32) && !defined(_WIN32_WCE)
 int __ortp_thread_join(ortp_thread_t thread, void **ptr){
 	int err=pthread_join(thread,ptr);
 	if (err!=0) {
@@ -125,7 +125,7 @@ int __ortp_thread_join(ortp_thread_t thread, void **ptr){
 	return err;
 }
 #endif
-#ifdef _WIN32
+#if	defined(_WIN32) || defined(_WIN32_WCE)
 
 int WIN_mutex_init(ortp_mutex_t *mutex, void *attr)
 {	
@@ -163,6 +163,10 @@ static unsigned WINAPI thread_starter(void *data){
 	return (DWORD)ret;
 }
 
+#if defined _WIN32_WCE
+#    define _beginthreadex	CreateThread
+#    define	_endthreadex	ExitThread
+#endif
 
 int WIN_thread_create(ortp_thread_t *th, void *attr, void * (*func)(void *), void *data)
 {
@@ -186,7 +190,7 @@ int WIN_thread_join(ortp_thread_t thread_h, void **unused)
 int WIN_cond_init(ortp_cond_t *cond, void *attr)
 {
 	*cond=CreateEvent(NULL, FALSE, FALSE, NULL);
-    return 0;
+	return 0;
 }
 
 int WIN_cond_wait(ortp_cond_t* hCond, ortp_mutex_t * hMutex)
@@ -195,7 +199,7 @@ int WIN_cond_wait(ortp_cond_t* hCond, ortp_mutex_t * hMutex)
 	WIN_mutex_unlock(hMutex);	
 	WaitForSingleObject(*hCond, INFINITE);
 	WIN_mutex_lock(hMutex);
-    return 0;
+	return 0;
 }
 
 int WIN_cond_signal(ortp_cond_t * hCond)
@@ -217,6 +221,19 @@ int WIN_cond_destroy(ortp_cond_t * hCond)
 }
 
 
+#if defined(_WIN32_WCE)
+#include <time.h>
+
+int
+gettimeofday (struct timeval *tv, void *tz)
+{
+  DWORD timemillis = GetTickCount();
+  tv->tv_sec  = timemillis/1000;
+  tv->tv_usec = (timemillis - (tv->tv_sec*1000)) * 1000;
+  return 0;
+}
+
+#else
 
 int gettimeofday (struct timeval *tv, void* tz) 
 { 
@@ -232,6 +249,8 @@ int gettimeofday (struct timeval *tv, void* tz)
 	return (0); 
 } 
 
+#endif
+
 const char *getWinSocketError(int error)
 {
 	static char buf[80];
