@@ -1419,6 +1419,8 @@ void rtp_session_reset (RtpSession * session)
 	session->rtp.hwrcv_extseq = 0;
 	session->rtp.hwrcv_since_last_SR=0;
 	session->rtp.snd_seq = 0;
+	rtp_session_clear_send_error_code(session);
+	rtp_session_clear_recv_error_code(session);
 	rtp_stats_reset(&session->rtp.stats);
 	rtp_session_resync(session);
 }
@@ -1511,6 +1513,21 @@ float rtp_session_compute_send_bandwidth(RtpSession *session){
 	return bw;
 }
 
+int rtp_session_get_last_send_error_code(RtpSession *session){
+	return session->rtp.send_errno;
+}
+
+void rtp_session_clear_send_error_code(RtpSession *session){
+	session->rtp.send_errno=0;
+}
+
+int rtp_session_get_last_recv_error_code(RtpSession *session){
+	return session->rtp.recv_errno;
+}
+
+void rtp_session_clear_recv_error_code(RtpSession *session){
+	session->rtp.send_errno=0;
+}
 
 /**
  * Destroys a rtp session.
