@@ -21,22 +21,11 @@
 #include <ortp/sessionset.h>
 #include "scheduler.h"
 
-/**
- *session_set_init:
- *@ss:	 a SessionSet statically allocated.
- *
- *	Initializes a session set. It is unusefull to call this function on a session set object
- *	returned by session_set_new().
- *
-**/
-
 
 /**
- *session_set_new:
- *
  * Allocates and initialize a new empty session set.
  *
- *Returns: the session set.
+ * @return the empty session set.
 **/
 SessionSet * session_set_new()
 {
@@ -47,8 +36,6 @@ SessionSet * session_set_new()
 
 
 /**
- *session_set_destroy:
- *@set:	a SessionSet
  * Destroys a session set.
  *
 **/
@@ -63,9 +50,9 @@ int session_set_and(SessionSet *sched_set, int maxs, SessionSet *user_set, Sessi
 	uint32_t *mask1,*mask2,*mask3;
 	int i=0;
 	int j,ret=0;
-	mask1=(uint32_t*)&sched_set->rtpset;
-	mask2=(uint32_t*)&user_set->rtpset;
-	mask3=(uint32_t*)&result_set->rtpset;
+	mask1=(uint32_t*)(void*)&sched_set->rtpset;
+	mask2=(uint32_t*)(void*)&user_set->rtpset;
+	mask3=(uint32_t*)(void*)&result_set->rtpset;
 	while(i<maxs+1){
 		*mask3=(*mask1) & (*mask2);	/* computes the AND between the two masks*/
 		/* and unset the sessions that have been found from the sched_set */
@@ -87,11 +74,6 @@ int session_set_and(SessionSet *sched_set, int maxs, SessionSet *user_set, Sessi
 }
 
 /**
- *session_set_select:
- *@recvs:		a set of rtp sessions to be watched for read events
- *@sends:		a set of rtp sessions to be watched for write events
- *@errors:		a set of rtp sessions to be watched for errors
- *
  *	This function performs similarly as libc select() function, but performs on #RtpSession 
  *	instead of file descriptors.
  *	session_set_select() suspends the calling process until some events arrive on one of the
@@ -108,7 +90,10 @@ int session_set_and(SessionSet *sched_set, int maxs, SessionSet *user_set, Sessi
  *	Sessions can be added to sets using session_set_set(), a session has to be tested to be 
  *	part of a set using session_set_is_set().
  *
- *Returns: the number of sessions on which the selected events happened.
+ * @param recvs a set of rtp sessions to be watched for read events
+ * @param sends a set of rtp sessions to be watched for write events
+ * @param errors a set of rtp sessions to be watched for errors
+ * @return: the number of sessions on which the selected events happened.
 **/
 int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 {
@@ -123,6 +108,7 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 		/* computes the SessionSet intersection (in the other words mask intersection) between
 		the mask given by the user and scheduler masks */
 		if (recvs!=NULL){
+			session_set_init(&temp);
 			bits=session_set_and(&sched->r_sessions,sched->all_max,recvs,&temp);
 			if (bits>0){
 				ret+=bits;
@@ -131,6 +117,7 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 			}
 		}
 		if (sends!=NULL){
+			session_set_init(&temp);
 			bits=session_set_and(&sched->w_sessions,sched->all_max,sends,&temp);
 			if (bits>0){
 				ret+=bits;
@@ -139,6 +126,7 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 			}
 		}
 		if (errors!=NULL){
+			session_set_init(&temp);
 			bits=session_set_and(&sched->e_sessions,sched->all_max,errors,&temp);
 			if (bits>0){
 				ret+=bits;
@@ -160,28 +148,3 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 	return -1;
 }
 
-/**
- *session_set_set:
- *@ss:		a set (#SessionSet object)
- *@rtpsession:	a rtp session
- *
- *	This macro adds rtp session @_session to set @_set.
-**/
-
-/**
- *session_set_is_set:
- *@ss:		a set (#SessionSet object)
- *@rtpsession:	a rtp session
- *
- *	This macro tests if @_session is part of @_set. 1 is returned if true, 0 else.
-**/
-
-/**
- *session_set_clr:
- *@ss:	a set of sessions.
- *@rtpsession: a rtp session.
- *
- *	Removes the @_session from the _set.
- *
- *
-**/
