@@ -111,6 +111,7 @@
 #include <string.h>
 
 #include "ortp/stun_udp.h"
+#include "ortp/ortp.h"
 
 #if !defined(WIN32) && !defined(_WIN32_WCE)
 int getErrno() { return errno; }
@@ -127,7 +128,7 @@ openPort( unsigned short port, unsigned int interfaceIp, bool_t verbose )
    fd = socket(PF_INET, SOCK_DGRAM, IPPROTO_UDP);
    if ( fd == INVALID_SOCKET )
    {
-      printf("Could not create a UDP socket:\n");
+	  ortp_error("stun_udp: Could not create a UDP socket");
       return INVALID_SOCKET;
    }
    
@@ -142,7 +143,7 @@ openPort( unsigned short port, unsigned int interfaceIp, bool_t verbose )
       addr.sin_addr.s_addr = htonl(interfaceIp);
       if (verbose )
       {
-         printf("Binding to interface 0x%lu\n",(unsigned long) htonl(interfaceIp));
+         ortp_message("Binding to interface 0x%lu\n",(unsigned long) htonl(interfaceIp));
       }
    }
 	
@@ -154,12 +155,12 @@ openPort( unsigned short port, unsigned int interfaceIp, bool_t verbose )
       {
          case 0:
          {
-            printf("Could not bind socket\n");;
+            ortp_error("stun_udp: Could not bind socket");;
             return INVALID_SOCKET;
          }
          case EADDRINUSE:
          {
-            printf("Port %i for receiving UDP is in use\n", port);
+            ortp_error("stun_udp: Port %i for receiving UDP is in use", port);
             return INVALID_SOCKET;
          }
          break;
@@ -167,7 +168,7 @@ openPort( unsigned short port, unsigned int interfaceIp, bool_t verbose )
          {
             if ( verbose ) 
             {
-               printf("Cannot assign requested address\n");
+               ortp_error("stun_udp: Cannot assign requested address");
             }
             return INVALID_SOCKET;
          }
@@ -175,10 +176,10 @@ openPort( unsigned short port, unsigned int interfaceIp, bool_t verbose )
          default:
          {
 #if !defined(_WIN32_WCE)
-			 printf("Could not bind UDP receive port Error=%i %s\n",
+			 ortp_error("stun_udp: Could not bind UDP receive port Error=%i %s",
                    e, strerror(e));
 #else
-			 printf("Could not bind UDP receive port Error=%i\n",
+			 ortp_error("stun_udp: Could not bind UDP receive port Error=%i",
                    e);
 #endif
             return INVALID_SOCKET;
@@ -188,7 +189,7 @@ openPort( unsigned short port, unsigned int interfaceIp, bool_t verbose )
    }
    if ( verbose )
    {
-      printf("Opened port %i with fd %i\n", port, fd);
+	   ortp_message("stun: opened port %i with fd %i\n", port, fd);
    }
    
    /* assert( fd != INVALID_SOCKET  ); */
@@ -218,7 +219,10 @@ getMessage( Socket fd, char* buf, int* len,
    int fdSetSize;
 #endif
 
-   assert( originalSize > 0 );
+   if (originalSize <= 0)
+   {
+	   return FALSE;
+   }
 
    tv.tv_sec=1;
    tv.tv_usec=0; /* 150 ms */
@@ -232,21 +236,21 @@ getMessage( Socket fd, char* buf, int* len,
       switch (e)
       {
          case ENOTSOCK:
-            printf("Error fd not a socket\n");
+            ortp_error("stun_udp: Error fd not a socket");
             break;
          case ECONNRESET:
-            printf("Error connection reset - host not reachable\n");
+            ortp_error("stun_udp: Error connection reset - host not reachable");
             break;
 				
          default:
-            printf("Socket Error=%i\n", e);
+            ortp_error("stun_udp: Socket Error=%i", e);
       }
       return FALSE;
    }
 
     if (err==0)
     {
-        printf("Connection timeout with stun server!\n");
+        ortp_error("stun_udp: Connection timeout with stun server!");
         *len = 0;
         return FALSE;
     }
@@ -267,14 +271,14 @@ getMessage( Socket fd, char* buf, int* len,
             switch (e)
             {
                 case ENOTSOCK:
-                    printf("Error fd not a socket\n");
+                    ortp_error("stun_udp: Error fd not a socket");
                     break;
                 case ECONNRESET:
-                    printf("Error connection reset - host not reachable\n");
+                    ortp_error("stun_udp: Error connection reset - host not reachable");
                     break;
         				
                 default:
-                    printf("Socket Error=%i\n", e);
+                    ortp_error("stun_udp: Socket Error=%i", e);
             }
         		
             return FALSE;
@@ -282,13 +286,13 @@ getMessage( Socket fd, char* buf, int* len,
         	
         if ( *len < 0 )
         {
-            printf("socket closed? negative len\n");
+            ortp_error("stun_udp: socket closed? negative len");
             return FALSE;
         }
             
         if ( *len == 0 )
         {
-            printf("socket closed? zero len\n");
+            ortp_error("stun_udp: socket closed? zero len");
             return FALSE;
         }
             
@@ -299,7 +303,7 @@ getMessage( Socket fd, char* buf, int* len,
         {
             if (verbose)
             {
-                printf("Received a message that was too large\n");
+                ortp_error("stun_udp: Received a message that was too large");
             }
             return FALSE;
         }
@@ -317,22 +321,24 @@ sendMessage( Socket fd, char* buf, int l,
              bool_t verbose)
 {
    int s;
-   assert( fd != INVALID_SOCKET );
+
+   if (fd == INVALID_SOCKET)
+	   return FALSE;
 
    if ( dstPort == 0 )
    {
       /* sending on a connected port */
-      assert( dstIp == 0 );
-		
       s = send(fd,buf,l,0);
    }
    else
    {
       struct sockaddr_in to;
       int toLen = sizeof(to);
-      assert( dstIp != 0 );
-      assert( dstPort != 0 );
-        
+      if (dstIp == 0)
+	  {
+		  ortp_error("stun_udp: invalid IP provided (dstIP==0)");
+		  return FALSE;
+	  }
 
       memset(&to,0,toLen);
         
@@ -357,15 +363,15 @@ sendMessage( Socket fd, char* buf, int l,
          break;
          case EAFNOSUPPORT:
          {
-            printf("err EAFNOSUPPORT in send\n");
+            ortp_error("stun_udp: err EAFNOSUPPORT in send");
          }
          break;
          default:
          {
 #if !defined(_WIN32_WCE)
-            printf("err %i %s in send\n", e, strerror(e));
+            ortp_error("stun_udp: err %i %s in send", e, strerror(e));
 #else
-            printf("err %i in send\n", e);
+            ortp_error("stun_udp: err %i in send", e);
 #endif
          }
       }
@@ -374,7 +380,7 @@ sendMessage( Socket fd, char* buf, int l,
     
    if ( s == 0 )
    {
-      printf("no data sent in send\n");
+      ortp_error("stun_udp: no data sent in send");
       return FALSE;
    }
     
@@ -382,7 +388,7 @@ sendMessage( Socket fd, char* buf, int l,
    {
       if (verbose)
       {
-         printf("only %i out of %i bytes sent\n", s, l);
+         ortp_error("stun_udp: only %i out of %i bytes sent", s, l);
       }
       return FALSE;
    }
@@ -403,9 +409,7 @@ initNetwork()
    if ( err != 0 ) 
    {
       /* could not find a usable WinSock DLL */
-      printf("Could not load winsock\n");
-      assert(0); /* is this is failing, try a different version that 2.2, 1.0 or later will likely work */
-      exit(1);
+      ortp_error("stun_udp: Could not load winsock");
    }
     
    /* Confirm that the WinSock DLL supports 2.2.*/
@@ -420,9 +424,7 @@ initNetwork()
       /* Tell the user that we could not find a usable */
       /* WinSock DLL.                                  */
       WSACleanup( );
-      printf("Bad winsock verion\n");
-      assert(0); /* is this is failing, try a different version that 2.2, 1.0 or later will likely work */
-      exit(1);
+      ortp_error("stun_udp: Wrong winsock (!= 2.2) version");
    }    
 #endif
 }
