@@ -29,20 +29,17 @@ PayloadType	payload_type_telephone_event={
 	NULL,	/* zero pattern N/A*/
 	0,		/*pattern_length N/A */
 	0,		/*	normal_bitrate */
-	"telephone-event",
-	0	/*flags */
+	"telephone-event",	/* MIME subtype */
+	0,		/* Audio Channels N/A */
+	0		/*flags */
 };
 
-/* tell if the session supports telephony events. For this the telephony events payload_type 
-	must be present in the rtp profile used by the session */
 /**
- *rtp_session_telephone_events_supported:
- *@session	:	a rtp session 
+ * Tells whether telephony events payload type is supported within the 
+ * context of the rtp session.
+ * @param session a rtp session 
  *
- *	Tells whether telephony events payload type is supported within the context of the rtp
- *	session.
- *
- *Returns: the payload type number used for telephony events if found, -1 if not found.
+ * @return the payload type number used for telephony events if found, -1 if not found.
 **/
 int rtp_session_telephone_events_supported(RtpSession *session)
 {
@@ -55,13 +52,11 @@ int rtp_session_telephone_events_supported(RtpSession *session)
 
 
 /**
- *rtp_session_send_telephone_events_supported:
- *@session	:	a rtp session 
+ * Tells whether telephone event payload type is supported for send within the 
+ * context of the rtp session.
+ * @param session a rtp session 
  *
- *	Tells whether sending telephony events payload type is supported within the context of the rtp
- *	session.
- *
- *Returns: the payload type number used for telephony events if found, -1 if not found.
+ * @return the payload type number used for telephony events if found, -1 if not found.
 **/
 int rtp_session_send_telephone_events_supported(RtpSession *session)
 {
@@ -72,15 +67,12 @@ int rtp_session_send_telephone_events_supported(RtpSession *session)
 }
 
 /**
- *rtp_session_recv_telephone_events_supported:
- *@session	:	a rtp session 
+ * Tells whether telephone event payload type is supported for receiving within the 
+ * context of the rtp session.
+ * @param session a rtp session 
  *
- *	Tells whether receiving telephony events payload type is supported within the context of the rtp
- *	session.
- *
- *Returns: the payload type number used for telephony events if found, -1 if not found.
-**/
-int rtp_session_recv_telephone_events_supported(RtpSession *session)
+ * @return the payload type number used for telephony events if found, -1 if not found.
+**/int rtp_session_recv_telephone_events_supported(RtpSession *session)
 {
 	/* search for a telephony event payload in the current profile */
 	session->rcv.telephone_events_pt=rtp_profile_get_payload_number_from_mime(session->rcv.profile,"telephone-event");
@@ -90,15 +82,14 @@ int rtp_session_recv_telephone_events_supported(RtpSession *session)
 
 
 /**
- *rtp_session_create_telephone_event_packet:
- *@session: a rtp session.
- *@start:	boolean to indicate if the marker bit should be set.
- *
  *	Allocates a new rtp packet to be used to add named telephony events. The application can use
  *	then rtp_session_add_telephone_event() to add named events to the packet.
  *	Finally the packet has to be sent with rtp_session_sendm_with_ts().
  *
- *Returns: a message block containing the rtp packet if successfull, NULL if the rtp session
+ * @param session a rtp session.
+ * @param start boolean to indicate if the marker bit should be set.
+ *
+ * @return a message block containing the rtp packet if successfull, NULL if the rtp session
  *cannot support telephony event (because the rtp profile it is bound to does not include
  *a telephony event payload type).
 **/
@@ -131,18 +122,17 @@ mblk_t	*rtp_session_create_telephone_event_packet(RtpSession *session, int start
 
 
 /**
- *rtp_session_add_telephone_event:
- *@session:	a rtp session.
- *@packet:	a rtp packet as a #mblk_t
- *@event:	the event type as described in rfc2833, ie one of the TEV_ macros.
- *@end:		boolean to indicate if the end bit should be set. (end of tone)
- *@volume:	the volume of the telephony tone, as described in rfc2833
- *@duration:the duration of the telephony tone, in timestamp unit.
+ *@param session a rtp session.
+ *@param packet a rtp packet as a mblk_t
+ *@param event the event type as described in rfc2833, ie one of the TEV_* macros.
+ *@param end a boolean to indicate if the end bit should be set. (end of tone)
+ *@param volume the volume of the telephony tone, as described in rfc2833
+ *@param duration the duration of the telephony tone, in timestamp unit.
  *
- *	Adds a named telephony event to a rtp packet previously allocated using
- *	rtp_session_create_telephone_event_packet().
+ * Adds a named telephony event to a rtp packet previously allocated using
+ * rtp_session_create_telephone_event_packet().
  *
- *Returns 0 on success.
+ *@return 0 on success.
 **/
 int rtp_session_add_telephone_event(RtpSession *session,
 			mblk_t *packet, uint8_t event, int end, uint8_t volume, uint16_t duration)
@@ -170,24 +160,30 @@ int rtp_session_add_telephone_event(RtpSession *session,
 	return 0;
 }
 /**
- *rtp_session_send_dtmf:
- *@session	: a rtp session
- *@dtmf		: a character meaning the dtmf (ex: '1', '#' , '9' ...)
- *@userts	: the timestamp
- *
- *	This functions creates telephony events packets for @dtmf and sends them.
+ *	This functions creates telephony events packets for dtmf and sends them.
  *	It uses rtp_session_create_telephone_event_packet() and
  *	rtp_session_add_telephone_event() to create them and finally
  *	rtp_session_sendm_with_ts() to send them.
  *
- *Returns:	0 if successfull, -1 if the session cannot support telephony events or if the dtmf
- *	given as argument is not valid.
+ * @param session a rtp session
+ * @param dtmf a character meaning the dtmf (ex: '1', '#' , '9' ...)
+ * @param userts the timestamp
+ * @return 0 if successfull, -1 if the session cannot support telephony events or if the dtmf given as argument is not valid.
 **/
 int rtp_session_send_dtmf(RtpSession *session, char dtmf, uint32_t userts)
 {
   return rtp_session_send_dtmf2(session, dtmf, userts, 480);
 }
 
+/**
+ * A variation of rtp_session_send_dtmf() with duration specified.
+ *
+ * @param session a rtp session
+ * @param dtmf a character meaning the dtmf (ex: '1', '#' , '9' ...)
+ * @param userts the timestamp
+ * @param duration duration of the dtmf in timestamp units
+ * @return 0 if successfull, -1 if the session cannot support telephony events or if the dtmf given as argument is not valid.
+**/
 int rtp_session_send_dtmf2(RtpSession *session, char dtmf, uint32_t userts, int duration)
 {
 	mblk_t *m1,*m2,*m3;
@@ -279,7 +275,7 @@ int rtp_session_send_dtmf2(RtpSession *session, char dtmf, uint32_t userts, int
 	
 	/* and now sends them */
 	rtp_session_sendm_with_ts(session,m1,userts);
-	rtp_session_sendm_with_ts(session,m2,userts+durationtier);
+	rtp_session_sendm_with_ts(session,m2,userts);
 	/* the last packet is sent three times in order to improve reliability*/
 	m1=copymsg(m3);
 	m2=copymsg(m3);
@@ -291,23 +287,22 @@ int rtp_session_send_dtmf2(RtpSession *session, char dtmf, uint32_t userts, int
 	it add one more copy for every buffer.
 	Using iomapped socket, it is possible to avoid the user to kernel copy.
 	*/
-	rtp_session_sendm_with_ts(session,m3,userts+durationtier+durationtier);
-	rtp_session_sendm_with_ts(session,m1,userts+durationtier+durationtier);
-	rtp_session_sendm_with_ts(session,m2,userts+durationtier+durationtier);
+	rtp_session_sendm_with_ts(session,m3,userts);
+	session->rtp.snd_seq--;
+	rtp_session_sendm_with_ts(session,m1,userts);
+	session->rtp.snd_seq--;
+	rtp_session_sendm_with_ts(session,m2,userts);
 	return 0;
 }
 
 
 /**
- *rtp_session_read_telephone_event:
- *@session: a rtp session from which telephony events are received.
- *@packet:	a rtp packet as a mblk_t.
- *@tab:		the address of a pointer.
- *
  *	Reads telephony events from a rtp packet. *@tab points to the beginning of the event buffer.
  *
- *Returns: the number of events in the packet if successfull, 0 if the packet did not
- *	contain telephony events.
+ * @param session a rtp session from which telephony events are received.
+ * @param packet a rtp packet as a mblk_t.
+ * @param tab the address of a pointer.
+ * @return the number of events in the packet if successfull, 0 if the packet did not contain telephony events.
 **/
 int rtp_session_read_telephone_event(RtpSession *session,
 		mblk_t *packet,telephone_event_t **tab)
