@@ -21,6 +21,7 @@
 #include <ortp/telephonyevents.h>
 #include <signal.h>
 #include <stdlib.h>
+#include <assert.h>
 #include <sys/types.h>
 #ifndef _WIN32
 #include <sys/time.h>
@@ -42,7 +43,7 @@ static char *help="usage: test_tevrecv	filename loc_port\n";
 
 int dtmf_count=0;
 
-void recv_tev_cb(RtpSession *session,gint type,gpointer user_data)
+void recv_tev_cb(RtpSession *session,int type,long user_data)
 {
 	printf("Receiving telephony event:%i\n",type);
 	if (type<16) printf("This is dtmf %c\n",dtmf_tab[type]);
@@ -52,11 +53,11 @@ void recv_tev_cb(RtpSession *session,gint type,gpointer user_data)
 int main(int argc, char *argv[])
 {
 	RtpSession *session;
-	char buffer[160];
+	unsigned char buffer[160];
 	int err;
 	FILE *outfile;
-	guint32 ts=0;
-	gint have_more;
+	uint32_t ts=0;
+	int have_more;
 
 	if (argc<3){
 		printf(help);
@@ -65,7 +66,6 @@ int main(int argc, char *argv[])
 
 	ortp_init();
 	ortp_scheduler_init();
-	ortp_set_debug_file("oRTP",stdout);
 	
 	/* set the telephony event payload type to 96 in the av profile.*/
 	rtp_profile_set_payload(&av_profile,96,&payload_type_telephone_event);
@@ -78,7 +78,7 @@ int main(int argc, char *argv[])
 	rtp_session_set_payload_type(session,0);
 	
 	/* register for telephony events */
-	rtp_session_signal_connect(session,"telephone-event",(RtpCallback)recv_tev_cb,NULL);
+	rtp_session_signal_connect(session,"telephone-event",(RtpCallback)recv_tev_cb,0);
 		
 	outfile=fopen(argv[1],"wb");
 	if (outfile==NULL) {
@@ -92,11 +92,12 @@ int main(int argc, char *argv[])
 		while (have_more){
 			err=rtp_session_recv_with_ts(session,buffer,160,ts,&have_more);
 			if (err>0) {
-				fwrite(buffer,1,err,outfile);
+				size_t ret = fwrite(buffer,1,err,outfile);
+				assert( ret == err );
 			}
 		}
 		ts+=160;
-		//g_message("Receiving packet.");
+		//ortp_message("Receiving packet.");
 	}
 	fclose(outfile);
 	rtp_session_destroy(session);
